
.*:     file format.*

Disassembly of section .text:

00000000 <main>:
   0:	b580      	push	{r7, lr}
   2:	af00      	add	r7, sp, #0
   4:	f000 fffc 	bl	1000 <.*>
   8:	bd80      	pop	{r7, pc}
   a:	bf00      	nop

