.*: Assembler messages:
.*:11: Error: operand 3 must be constant `addiu \$3,\$2,%lo\(bar\)'
.*:12: Error: operand 3 must be constant `daddiu \$3,\$2,%lo\(bar\)'
.*:14: Error: operand 2 must be constant `slti \$3,%lo\(bar\)'
.*:15: Error: operand 2 must be constant `sltiu \$3,%lo\(bar\)'
.*:17: Error: operand 3 must be constant `sll \$3,\$2,%lo\(bar\)'
.*:18: Error: operand 3 must be constant `sra \$3,\$2,%lo\(bar\)'
.*:19: Error: operand 3 must be constant `srl \$3,\$2,%lo\(bar\)'
.*:20: Error: operand 3 must be constant `dsll \$3,\$2,%lo\(bar\)'
.*:21: Error: operand 2 must be constant `dsra \$3,%lo\(bar\)'
.*:22: Error: operand 2 must be constant `dsrl \$3,%lo\(bar\)'
.*:24: Error: operand 1 must be constant `break %lo\(bar\)'
.*:25: Error: operand 1 must be constant `sdbbp %lo\(bar\)'
.*:27: Error: invalid operands `b %lo\(bar\)'
.*:28: Error: invalid operands `beqz \$3,%lo\(bar\)'
.*:29: Error: invalid operands `bnez \$3,%lo\(bar\)'
.*:30: Error: invalid operands `bteqz %lo\(bar\)'
.*:31: Error: invalid operands `btnez %lo\(bar\)'
.*:33: Error: invalid operands `jal %lo\(bar\)'
.*:34: Error: invalid operands `jalx %lo\(bar\)'
.*:36: Error: operand 3 must be constant `save \$31,\$16,%lo\(bar\)'
.*:37: Error: operand 3 must be constant `restore \$31,\$16,%lo\(bar\)'
.*:39: Error: operand 6 must be constant `asmacro 0,0,0,0,0,%lo\(bar\)'
.*:40: Error: operand 5 must be constant `asmacro 0,0,0,0,%lo\(bar\),0'
.*:41: Error: operand 4 must be constant `asmacro 0,0,0,%lo\(bar\),0,0'
.*:42: Error: operand 3 must be constant `asmacro 0,0,%lo\(bar\),0,0,0'
.*:43: Error: operand 2 must be constant `asmacro 0,%lo\(bar\),0,0,0,0'
.*:44: Error: operand 1 must be constant `asmacro %lo\(bar\),0,0,0,0,0'
