#readelf: -wl
#source: brokw-3.s
#as: --em=criself --gdwarf2

# Long broken word table.
#...
 Line Number Statements:
  \[0x.*\]  Extended opcode 2: set Address to 0x0
  \[0x.*\]  Special opcode .*: advance Address by 0 to 0x0 and Line by 3 to 4
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x2 and Line by 4 to 8
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0x6 and Line by 1 to 9
  \[0x.*\]  Special opcode .*: advance Address by 4 to 0xa and Line by 1 to 10
  \[0x.*\]  Advance Line by 47 to 57
  \[0x.*\]  Advance PC by 104 to 0x72
  \[0x.*\]  Copy
  \[0x.*\]  Advance Line by 10 to 67
  \[0x.*\]  Advance PC by 260 to 0x176
  \[0x.*\]  Copy
  \[0x.*\]  Advance PC by 32770 to 0x8178
  \[0x.*\]  Special opcode .*: advance Address by 0 to 0x8178 and Line by 4 to 71
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x817a and Line by 1 to 72
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x817c and Line by 1 to 73
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x817e and Line by 1 to 74
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x8180 and Line by 1 to 75
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x8182 and Line by 1 to 76
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x8184 and Line by 1 to 77
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x8186 and Line by 1 to 78
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x8188 and Line by 1 to 79
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x818a and Line by 1 to 80
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x818c and Line by 1 to 81
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x818e and Line by 1 to 82
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x8190 and Line by 1 to 83
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x8192 and Line by 1 to 84
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x8194 and Line by 1 to 85
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x8196 and Line by 1 to 86
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x8198 and Line by 1 to 87
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x819a and Line by 1 to 88
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x819c and Line by 1 to 89
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x819e and Line by 1 to 90
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81a0 and Line by 1 to 91
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81a2 and Line by 1 to 92
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81a4 and Line by 1 to 93
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81a6 and Line by 1 to 94
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81a8 and Line by 1 to 95
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81aa and Line by 1 to 96
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81ac and Line by 1 to 97
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81ae and Line by 1 to 98
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81b0 and Line by 1 to 99
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81b2 and Line by 1 to 100
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81b4 and Line by 1 to 101
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81b6 and Line by 1 to 102
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81b8 and Line by 1 to 103
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81ba and Line by 1 to 104
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81bc and Line by 1 to 105
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81be and Line by 1 to 106
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81c0 and Line by 1 to 107
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81c2 and Line by 1 to 108
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81c4 and Line by 1 to 109
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81c6 and Line by 1 to 110
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81c8 and Line by 1 to 111
  \[0x.*\]  Special opcode .*: advance Address by 2 to 0x81ca and Line by 1 to 112
  \[0x.*\]  Advance PC by 2 to 0x81cc
  \[0x.*\]  Extended opcode 1: End of Sequence
