.*asi-arch-error.s: Assembler messages:
.*asi-arch-error.s:3: Error: Architecture mismatch on "ldda \[%g0]#ASI_FL16_P,%f0".
.*asi-arch-error.s:3: \(Requires v9b\|v9c\|v9d\|v9e\|v9v\|v9m.*; requested architecture is v9.\)
