.*: Assembler messages:
.*:5: Error: operand 1 out of range `break -1'
.*:6: Error: operand 1 out of range `break 65536'
.*:7: Error: operand 1 out of range `break 0x10000000000000000'
.*:8: Error: operand 1 must be an immediate expression `break \$3'
.*:9: Error: invalid operands `break \(\$3\)'
.*:10: Error: register value used as expression `break 0\+\$3'
.*:11: Error: register value used as expression `break \(\(\$3\)\)'
