.*: Assembler messages:
.*:13: Error: operand value out of range for instruction
.*:14: Error: operand value out of range for instruction
.*:15: Error: operand value out of range for instruction
.*:16: Error: operand value out of range for instruction
.*:17: Error: unsupported relocation
.*:18: Error: unsupported relocation
