#objdump: -d --prefix-addresses
#name: nds32 convert 32 to 16 (v2 instructions)
#as: -Os -mno-reduced-regs

# Test the convert 32bits to 16bits

.*:     file format .*


Disassembly of section .text:
0+0000 .*
0+0002 .*
0+0004 .*
0+0006 .*
0+0008 .*
