.*: Assembler messages:
.*:[0-9]*: Error:.* ambiguous .* `vcvtneps2bf16'
.*:[0-9]*: Error:.* ambiguous .* `vcvtpd2dq'
.*:[0-9]*: Error:.* ambiguous .* `vcvtpd2ps'
.*:[0-9]*: Error:.* ambiguous .* `vcvtpd2udq'
.*:[0-9]*: Error:.* ambiguous .* `vcvttpd2dq'
.*:[0-9]*: Error:.* ambiguous .* `vcvttpd2udq'
