	.section ".data.a0","aw",%progbits
	.byte 0x00
	.byte 0x01
	.byte 0x02
	.byte 0x03
	.byte 0x04
	.byte 0x05
	.byte 0x06
	.byte 0x07
	.section ".data.a1","aw",%progbits
	.byte 0x10
	.byte 0x11
	.byte 0x12
	.byte 0x13
	.byte 0x14
	.byte 0x15
	.byte 0x16
	.byte 0x17
