.*: Assembler messages:
.*:40: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:42: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:44: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:46: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:48: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:50: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:52: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:54: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:56: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:82: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:84: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:86: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:88: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:90: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:92: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:94: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:96: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:98: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
