.*fpcmpshl-diag.s: Assembler messages:
.*fpcmpshl-diag.s:3: Error: Illegal operands: imm2 immediate operand out of range.*
.*fpcmpshl-diag.s:4: Error: Illegal operands
.*fpcmpshl-diag.s:5: Error: Illegal operands
.*fpcmpshl-diag.s:6: Error: Illegal operands
.*fpcmpshl-diag.s:7: Error: Illegal operands
