[^:]*: Assembler messages:
.*: Warning: instruction opens new dependency sequence without ending previous one -- `movprfx z2,z3'
.*: Warning: output register of preceding `movprfx' used as input at operand 3 -- `neg z2.s,p0/m,z2.s'
