	.text
	.globl	start
	.type	start, @function
start:
	.globl	_start
	.type	_start, @function
_start:
	.globl	__start
	.type	__start, @function
__start:
	.globl	main
	.type	main, @function
main:
	.globl	_main
	.type	_main, @function
_main:
	.dc.a 0
