	.text
_start:
	mtvsrbm 0,1
	mtvsrhm 2,3
	mtvsrwm 4,5
	mtvsrdm 6,7
	mtvsrqm 8,9
	mtvsrbmi 10,0x1234
	vexpandbm 11,12
	vexpandhm 13,14
	vexpandwm 15,16
	vexpanddm 17,18
	vexpandqm 19,20
	vextractbm 21,22
	vextracthm 23,24
	vextractwm 25,26
	vextractdm 27,28
	vextractqm 29,30
	vcntmbb 31,0,0
	vcntmbh 30,1,1
	vcntmbw 29,2,1
	vcntmbd 28,3,0
