.*: Assembler messages:
.*:2: Error: An immediate value in a source operand is inappropriate
.*:2: Error: Invalid instruction: "st d0,#2"
.*:2: Error: First invalid token: "d0,#2"
.*:3: Error: An immediate value in a source operand is inappropriate
.*:3: Error: Invalid instruction: "st s,#4"
.*:3: Error: First invalid token: ""
.*:4: Error: An immediate value in a source operand is inappropriate
.*:4: Error: Invalid instruction: "mov.b d0,#4"
.*:4: Error: First invalid token: ""
.*:5: Error: An immediate value in a source operand is inappropriate
.*:5: Error: Invalid instruction: "inc.b #1"
.*:5: Error: First invalid token: "\(null\)"
.*:6: Error: An immediate value in a source operand is inappropriate
.*:6: Error: Invalid instruction: "dec.b #12"
.*:6: Error: First invalid token: "\(null\)"
.*:7: Error: An immediate value in a source operand is inappropriate
.*:7: Error: Invalid instruction: "com.w #1"
.*:7: Error: First invalid token: "\(null\)"
.*:8: Error: An immediate value in a source operand is inappropriate
.*:8: Error: Invalid instruction: "neg.l #-1"
.*:8: Error: First invalid token: "\(null\)"
.*:9: Error: An immediate value in a source operand is inappropriate
.*:9: Error: Invalid instruction: "ror.b #3"
.*:9: Error: First invalid token: "\(null\)"
