.*movi.s: Assembler messages:
.*movi.s:9: Error: immediate value 536870912 out of range -32768 to 32767
.*movi.s:12: Error: immediate value -65536 out of range -32768 to 32767
.*movi.s:15: Error: immediate value 4294901760 out of range 0 to 65535
.*movi.s:16: Error: immediate value 4294901760 out of range 0 to 65535
.*movi.s:17: Error: immediate value 4294901760 out of range 0 to 65535
