Primary GOT:
 Canonical gp value: ffffffff80000010

 Reserved entries:
           Address     Access          Initial Purpose
  ffffffff7fff8020 -32752\(gp\) 0000000000000000 Lazy resolver
  ffffffff7fff8028 -32744\(gp\) 8000000000000000 Module pointer \(GNU extension\)

PLT GOT:

 Reserved entries:
           Address          Initial Purpose
  ffffffff7fff8000 0000000000000000 PLT lazy resolver
  ffffffff7fff8008 0000000000000000 Module pointer

 Entries:
           Address          Initial         Sym\.Val\. Type    Ndx Name
  ffffffff7fff8010 ffffffff10000280 0000000000000000 FUNC    UND bar
