#objdump: -d
#name:    
#source:  inc.s


.*:     file format elf32-s12z


Disassembly of section .text:

00000000 <L1>:
   0:	30          	inc d2
   1:	31          	inc d3
   2:	32          	inc d4
   3:	33          	inc d5
   4:	34          	inc d0
   5:	35          	inc d1
   6:	36          	inc d6
   7:	37          	inc d7
