.*: Assembler messages:
.*:3: Error: Cannot move A1 to low half of register. Input text was A1.
.*:4: Error: Cannot move A0 to high half of register. Input text was A0.
.*:5: Error: Cannot move A1 to even register.
.*:6: Error: Cannot move A0 to odd register.
.*:7: Error: Unsupported register move.
