.*: Assembler messages:
.*: selected processor does not support instruction -- `vmrs r1,FPSCR_nzcvqc'
.*: selected processor does not support instruction -- `vmrs r2,VPR'
.*: selected processor does not support instruction -- `vmrs r3,P0'
.*: selected processor does not support instruction -- `vmrs r4,FPCXT_NS'
.*: selected processor does not support instruction -- `vmrs r5,FPCXT_S'
.*: selected processor does not support instruction -- `vmsr fpscr_nzcvqc,r1'
.*: selected processor does not support instruction -- `vmsr vpr,r2'
.*: selected processor does not support instruction -- `vmsr p0,r3'
.*: selected processor does not support instruction -- `vmsr fpcxt_ns,r4'
.*: selected processor does not support instruction -- `vmsr fpcxt_s,r5'
