[^:]*: Assembler messages:
[^:]*:10: Error: cannot honor width suffix -- `muleq.n r0,r0,r8'
[^:]*:12: Error: cannot honor width suffix -- `muleq.n r0,r1,r1'
[^:]*:13: Error: cannot honor width suffix -- `muleq.n r0,r1,r2'
[^:]*:15: Error: Thumb-2 MUL must not set flags -- `mulseq r0,r0,r1'
[^:]*:17: Error: Thumb-2 MUL must not set flags -- `muls.w r0,r0,r1'
[^:]*:19: Error: Thumb-2 MUL must not set flags -- `muls r0,r0,r8'
[^:]*:20: Error: Thumb-2 MUL must not set flags -- `muls r0,r8,r0'
