	.file	"dwp_test_1b.cc"
	.text
.Ltext0:
	.globl	c3
	.bss
	.align 4
	.type	c3, @object
	.size	c3, 4
c3:
	.zero	4
	.text
	.globl	_Z4t16av
	.type	_Z4t16av, @function
_Z4t16av:
.LFB1:
	.file 1 "dwp_test_1b.cc"
	.loc 1 33 0
	.cfi_startproc
	pushq	%rbp
	.cfi_def_cfa_offset 16
	.cfi_offset 6, -16
	movq	%rsp, %rbp
	.cfi_def_cfa_register 6
	.loc 1 34 0
	call	_Z3f10v
	cmpl	$135, %eax
	sete	%al
	.loc 1 35 0
	popq	%rbp
	.cfi_def_cfa 7, 8
	ret
	.cfi_endproc
.LFE1:
	.size	_Z4t16av, .-_Z4t16av
.Letext0:
	.file 2 "dwp_test.h"
	.section	.debug_types.dwo,"G",@progbits,wt.bb2916f0c1bd34b5,comdat
	.long	0x119
	.value	0x4
	.long	.Ldebug_abbrev0
	.byte	0x8
	.byte	0xbb
	.byte	0x29
	.byte	0x16
	.byte	0xf0
	.byte	0xc1
	.byte	0xbd
	.byte	0x34
	.byte	0xb5
	.long	0x25
	.uleb128 0x1
	.byte	0x4
	.byte	0x8a
	.byte	0xda
	.byte	0x59
	.byte	0x6e
	.byte	0x4d
	.byte	0x5c
	.byte	0xa
	.byte	0x88
	.long	.Lskeleton_debug_line0
	.uleb128 0x2
	.string	"C3"
	.byte	0x4
	.byte	0x2
	.byte	0x2f
	.long	0xfc
	.uleb128 0x3
	.string	"member1"
	.byte	0x2
	.byte	0x36
	.long	0xfc
	.byte	0
	.byte	0x1
	.uleb128 0x4
	.string	"testcase1"
	.byte	0x2
	.byte	0x32
	.string	"_ZN2C39testcase1Ev"
	.long	0x103
	.byte	0x1
	.long	0x6e
	.long	0x74
	.uleb128 0x5
	.long	0x10b
	.byte	0
	.uleb128 0x4
	.string	"testcase2"
	.byte	0x2
	.byte	0x33
	.string	"_ZN2C39testcase2Ev"
	.long	0x103
	.byte	0x1
	.long	0xa1
	.long	0xa7
	.uleb128 0x5
	.long	0x10b
	.byte	0
	.uleb128 0x4
	.string	"testcase3"
	.byte	0x2
	.byte	0x34
	.string	"_ZN2C39testcase3Ev"
	.long	0x103
	.byte	0x1
	.long	0xd4
	.long	0xda
	.uleb128 0x5
	.long	0x10b
	.byte	0
	.uleb128 0x6
	.string	"f4"
	.byte	0x2
	.byte	0x35
	.string	"_ZN2C32f4Ev"
	.long	0x111
	.byte	0x1
	.long	0xf5
	.uleb128 0x5
	.long	0x10b
	.byte	0
	.byte	0
	.uleb128 0x7
	.byte	0x4
	.byte	0x5
	.string	"int"
	.uleb128 0x7
	.byte	0x1
	.byte	0x2
	.string	"bool"
	.uleb128 0x8
	.byte	0x8
	.long	0x25
	.uleb128 0x8
	.byte	0x8
	.long	0x117
	.uleb128 0x9
	.long	0x103
	.byte	0
	.section	.debug_types,"G",@progbits,wt.bb2916f0c1bd34b5,comdat
	.long	0x6f
	.value	0x4
	.long	.Lskeleton_debug_abbrev0
	.byte	0x8
	.byte	0xbb
	.byte	0x29
	.byte	0x16
	.byte	0xf0
	.byte	0xc1
	.byte	0xbd
	.byte	0x34
	.byte	0xb5
	.long	0
	.uleb128 0x2
	.string	"/home/ccoutant/opensource/binutils-git/binutils/gold/testsuite"
	.string	"dwp_test_1b.dwo"
	.long	.Ldebug_pubnames0
	.long	.Ldebug_pubtypes0
	.long	.Ldebug_addr0
	.section	.debug_info.dwo,"e",@progbits
.Ldebug_info0:
	.long	0xcb
	.value	0x4
	.long	.Ldebug_abbrev0
	.byte	0x8
	.uleb128 0xa
	.string	"GNU C++ 4.7.x-google 20120720 (prerelease)"
	.byte	0x4
	.string	"dwp_test_1b.cc"
	.string	"/home/ccoutant/opensource/binutils-git/binutils/gold/testsuite"
	.byte	0xf6
	.byte	0xef
	.byte	0x47
	.byte	0xa2
	.byte	0x3e
	.byte	0xc1
	.byte	0x6e
	.byte	0xbd
	.uleb128 0x7
	.byte	0x4
	.byte	0x5
	.string	"int"
	.uleb128 0x7
	.byte	0x1
	.byte	0x2
	.string	"bool"
	.uleb128 0xb
	.string	"t16a"
	.byte	0x1
	.byte	0x20
	.string	"_Z4t16av"
	.long	0x95
	.uleb128 0
	.quad	.LFE1-.LFB1
	.uleb128 0x1
	.byte	0x9c
	.uleb128 0xc
	.string	"c3"
	.byte	0x1
	.byte	0x1d
	.byte	0xbb
	.byte	0x29
	.byte	0x16
	.byte	0xf0
	.byte	0xc1
	.byte	0xbd
	.byte	0x34
	.byte	0xb5
	.uleb128 0x2
	.byte	0xfb
	.uleb128 0x1
	.byte	0
	.section	.debug_info,"",@progbits
.Lskeleton_debug_info0:
	.long	0x7f
	.value	0x4
	.long	.Lskeleton_debug_abbrev0
	.byte	0x8
	.uleb128 0x1
	.quad	.Ltext0
	.quad	.Letext0-.Ltext0
	.long	.Ldebug_line0
	.byte	0xf6
	.byte	0xef
	.byte	0x47
	.byte	0xa2
	.byte	0x3e
	.byte	0xc1
	.byte	0x6e
	.byte	0xbd
	.string	"/home/ccoutant/opensource/binutils-git/binutils/gold/testsuite"
	.string	"dwp_test_1b.dwo"
	.long	.Ldebug_pubnames0
	.long	.Ldebug_pubtypes0
	.long	.Ldebug_addr0
	.section	.debug_abbrev,"",@progbits
.Lskeleton_debug_abbrev0:
	.uleb128 0x1
	.uleb128 0x11
	.byte	0
	.uleb128 0x11
	.uleb128 0x1
	.uleb128 0x12
	.uleb128 0x7
	.uleb128 0x10
	.uleb128 0x17
	.uleb128 0x2131
	.uleb128 0x7
	.uleb128 0x1b
	.uleb128 0x8
	.uleb128 0x2130
	.uleb128 0x8
	.uleb128 0x2134
	.uleb128 0x17
	.uleb128 0x2135
	.uleb128 0x17
	.uleb128 0x2133
	.uleb128 0x17
	.byte	0
	.byte	0
	.uleb128 0x2
	.uleb128 0x41
	.byte	0
	.uleb128 0x1b
	.uleb128 0x8
	.uleb128 0x2130
	.uleb128 0x8
	.uleb128 0x2134
	.uleb128 0x17
	.uleb128 0x2135
	.uleb128 0x17
	.uleb128 0x2133
	.uleb128 0x17
	.byte	0
	.byte	0
	.byte	0
	.section	.debug_abbrev.dwo,"e",@progbits
.Ldebug_abbrev0:
	.uleb128 0x1
	.uleb128 0x41
	.byte	0x1
	.uleb128 0x13
	.uleb128 0xb
	.uleb128 0x210f
	.uleb128 0x7
	.uleb128 0x10
	.uleb128 0x17
	.byte	0
	.byte	0
	.uleb128 0x2
	.uleb128 0x2
	.byte	0x1
	.uleb128 0x3
	.uleb128 0x8
	.uleb128 0xb
	.uleb128 0xb
	.uleb128 0x3a
	.uleb128 0xb
	.uleb128 0x3b
	.uleb128 0xb
	.uleb128 0x1
	.uleb128 0x13
	.byte	0
	.byte	0
	.uleb128 0x3
	.uleb128 0xd
	.byte	0
	.uleb128 0x3
	.uleb128 0x8
	.uleb128 0x3a
	.uleb128 0xb
	.uleb128 0x3b
	.uleb128 0xb
	.uleb128 0x49
	.uleb128 0x13
	.uleb128 0x38
	.uleb128 0xb
	.uleb128 0x32
	.uleb128 0xb
	.byte	0
	.byte	0
	.uleb128 0x4
	.uleb128 0x2e
	.byte	0x1
	.uleb128 0x3f
	.uleb128 0x19
	.uleb128 0x3
	.uleb128 0x8
	.uleb128 0x3a
	.uleb128 0xb
	.uleb128 0x3b
	.uleb128 0xb
	.uleb128 0x6e
	.uleb128 0x8
	.uleb128 0x49
	.uleb128 0x13
	.uleb128 0x32
	.uleb128 0xb
	.uleb128 0x3c
	.uleb128 0x19
	.uleb128 0x64
	.uleb128 0x13
	.uleb128 0x1
	.uleb128 0x13
	.byte	0
	.byte	0
	.uleb128 0x5
	.uleb128 0x5
	.byte	0
	.uleb128 0x49
	.uleb128 0x13
	.uleb128 0x34
	.uleb128 0x19
	.byte	0
	.byte	0
	.uleb128 0x6
	.uleb128 0x2e
	.byte	0x1
	.uleb128 0x3f
	.uleb128 0x19
	.uleb128 0x3
	.uleb128 0x8
	.uleb128 0x3a
	.uleb128 0xb
	.uleb128 0x3b
	.uleb128 0xb
	.uleb128 0x6e
	.uleb128 0x8
	.uleb128 0x49
	.uleb128 0x13
	.uleb128 0x32
	.uleb128 0xb
	.uleb128 0x3c
	.uleb128 0x19
	.uleb128 0x64
	.uleb128 0x13
	.byte	0
	.byte	0
	.uleb128 0x7
	.uleb128 0x24
	.byte	0
	.uleb128 0xb
	.uleb128 0xb
	.uleb128 0x3e
	.uleb128 0xb
	.uleb128 0x3
	.uleb128 0x8
	.byte	0
	.byte	0
	.uleb128 0x8
	.uleb128 0xf
	.byte	0
	.uleb128 0xb
	.uleb128 0xb
	.uleb128 0x49
	.uleb128 0x13
	.byte	0
	.byte	0
	.uleb128 0x9
	.uleb128 0x15
	.byte	0
	.uleb128 0x49
	.uleb128 0x13
	.byte	0
	.byte	0
	.uleb128 0xa
	.uleb128 0x11
	.byte	0x1
	.uleb128 0x25
	.uleb128 0x8
	.uleb128 0x13
	.uleb128 0xb
	.uleb128 0x3
	.uleb128 0x8
	.uleb128 0x1b
	.uleb128 0x8
	.uleb128 0x2131
	.uleb128 0x7
	.byte	0
	.byte	0
	.uleb128 0xb
	.uleb128 0x2e
	.byte	0
	.uleb128 0x3f
	.uleb128 0x19
	.uleb128 0x3
	.uleb128 0x8
	.uleb128 0x3a
	.uleb128 0xb
	.uleb128 0x3b
	.uleb128 0xb
	.uleb128 0x6e
	.uleb128 0x8
	.uleb128 0x49
	.uleb128 0x13
	.uleb128 0x11
	.uleb128 0x1f01
	.uleb128 0x12
	.uleb128 0x7
	.uleb128 0x40
	.uleb128 0x18
	.uleb128 0x2116
	.uleb128 0x19
	.byte	0
	.byte	0
	.uleb128 0xc
	.uleb128 0x34
	.byte	0
	.uleb128 0x3
	.uleb128 0x8
	.uleb128 0x3a
	.uleb128 0xb
	.uleb128 0x3b
	.uleb128 0xb
	.uleb128 0x49
	.uleb128 0x20
	.uleb128 0x3f
	.uleb128 0x19
	.uleb128 0x2
	.uleb128 0x18
	.byte	0
	.byte	0
	.byte	0
	.section	.debug_gnu_pubnames,"",@progbits
.Ldebug_pubnames0:
	.long	0x20
	.value	0x2
	.long	.Lskeleton_debug_info0
	.long	0xcf
	.long	0x9d
	.byte	0x30
	.string	"t16a"
	.long	0xbd
	.byte	0x20
	.string	"c3"
	.long	0
	.section	.debug_gnu_pubtypes,"",@progbits
.Ldebug_pubtypes0:
	.long	0x29
	.value	0x2
	.long	.Lskeleton_debug_info0
	.long	0xcf
	.long	0x8e
	.byte	0x90
	.string	"int"
	.long	0x95
	.byte	0x90
	.string	"bool"
	.long	0
	.byte	0x10
	.string	"C3"
	.long	0
	.section	.debug_aranges,"",@progbits
	.long	0x2c
	.value	0x2
	.long	.Lskeleton_debug_info0
	.byte	0x8
	.byte	0
	.value	0
	.value	0
	.quad	.Ltext0
	.quad	.Letext0-.Ltext0
	.quad	0
	.quad	0
	.section	.debug_line,"",@progbits
.Ldebug_line0:
	.section	.debug_line.dwo,"e",@progbits
.Lskeleton_debug_line0:
	.long	.LELT0-.LSLT0
.LSLT0:
	.value	0x4
	.long	.LELTP0-.LASLTP0
.LASLTP0:
	.byte	0x1
	.byte	0x1
	.byte	0x1
	.byte	0xf6
	.byte	0xf2
	.byte	0xd
	.byte	0
	.byte	0x1
	.byte	0x1
	.byte	0x1
	.byte	0x1
	.byte	0
	.byte	0
	.byte	0
	.byte	0x1
	.byte	0
	.byte	0
	.byte	0x1
	.byte	0
	.string	"dwp_test_1b.cc"
	.uleb128 0
	.uleb128 0
	.uleb128 0
	.string	"dwp_test.h"
	.uleb128 0
	.uleb128 0
	.uleb128 0
	.byte	0
.LELTP0:
.LELT0:
	.section	.debug_addr,"",@progbits
.Ldebug_addr0:
	.quad	.LFB1
	.quad	c3
	.ident	"GCC: (Google_crosstoolv16-gcc-4.7.x-grtev3) 4.7.x-google 20120720 (prerelease)"
	.section	.note.GNU-stack,"",@progbits
