.*Assembler messages:
.*Warning: Invalid CSR `ubadaddr' for the privilege spec `1.11'
.*Warning: Invalid CSR `sbadaddr' for the privilege spec `1.11'
.*Warning: Invalid CSR `sptbr' for the privilege spec `1.11'
.*Warning: Invalid CSR `mbadaddr' for the privilege spec `1.11'
.*Warning: Invalid CSR `mucounteren' for the privilege spec `1.11'
.*Warning: Invalid CSR `hstatus' for the privilege spec `1.11'
.*Warning: Invalid CSR `hedeleg' for the privilege spec `1.11'
.*Warning: Invalid CSR `hideleg' for the privilege spec `1.11'
.*Warning: Invalid CSR `hie' for the privilege spec `1.11'
.*Warning: Invalid CSR `htvec' for the privilege spec `1.11'
.*Warning: Invalid CSR `hscratch' for the privilege spec `1.11'
.*Warning: Invalid CSR `hepc' for the privilege spec `1.11'
.*Warning: Invalid CSR `hcause' for the privilege spec `1.11'
.*Warning: Invalid CSR `hbadaddr' for the privilege spec `1.11'
.*Warning: Invalid CSR `hip' for the privilege spec `1.11'
.*Warning: Invalid CSR `mbase' for the privilege spec `1.11'
.*Warning: Invalid CSR `mbound' for the privilege spec `1.11'
.*Warning: Invalid CSR `mibase' for the privilege spec `1.11'
.*Warning: Invalid CSR `mibound' for the privilege spec `1.11'
.*Warning: Invalid CSR `mdbase' for the privilege spec `1.11'
.*Warning: Invalid CSR `mdbound' for the privilege spec `1.11'
.*Warning: Invalid CSR `mscounteren' for the privilege spec `1.11'
.*Warning: Invalid CSR `mhcounteren' for the privilege spec `1.11'
