.*warn_noat.s: Assembler messages:
.*warn_noat.s:2: Warning: Register at \(r1\) can sometimes be corrupted by assembler optimizations.
Use .set noat to turn off those optimizations \(and this warning\).
.*warn_noat.s:8: Warning: Register at \(r1\) can sometimes be corrupted by assembler optimizations.
Use .set noat to turn off those optimizations \(and this warning\).
