        .file 1 "x.c"
        mov r1 = r35
        .loc 1 4 0
        nop 0
        mov r36 = r8
        br.call.sptk.many b0 = _U_Qfcnvff_quad_to_sgl#
        .loc 1 5 0
        .loc 1 4 0
        mov r1 = r35
