[^:]*: Assembler messages:
[^:]*:3: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:4: Warning: instruction is UNPREDICTABLE with PC operand
[^:]*:5: Error: bad type for scalar -- `vmov.64 q0\[0\],r0'
[^:]*:6: Error: scalar index out of range -- `vmov.8 q0\[16\],r0'
[^:]*:7: Error: scalar index out of range -- `vmov.16 q0\[8\],r0'
[^:]*:8: Error: scalar index out of range -- `vmov.32 q0\[4\],r0'
[^:]*:10: Error: syntax error -- `vmovt.8 q0\[0\],r0'
[^:]*:11: Error: syntax error -- `vmovt.8 q0\[0\],r0'
[^:]*:13: Error: instruction not allowed in IT block -- `vmov.8 q0\[0\],r0'
[^:]*:14: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:15: Warning: instruction is UNPREDICTABLE with PC operand
[^:]*:16: Error: bad type for scalar -- `vmov.u64 r0,q0\[0\]'
[^:]*:17: Error: bad type for scalar -- `vmov.s64 r0,q0\[0\]'
[^:]*:18: Error: bad type for scalar -- `vmov.64 r0,q0\[0\]'
[^:]*:19: Error: bad type for scalar -- `vmov.8 r0,q0\[0\]'
[^:]*:20: Error: bad type for scalar -- `vmov.16 r0,q0\[0\]'
[^:]*:21: Error: bad type for scalar -- `vmov.f16 r0,q0\[0\]'
[^:]*:22: Error: scalar index out of range -- `vmov.u8 r0,q0\[16\]'
[^:]*:23: Error: scalar index out of range -- `vmov.u16 r0,q0\[8\]'
[^:]*:24: Error: scalar index out of range -- `vmov.32 r0,q0\[4\]'
[^:]*:26: Error: syntax error -- `vmovt.u8 r0,q0\[0\]'
[^:]*:27: Error: syntax error -- `vmovt.u8 r0,q0\[0\]'
[^:]*:29: Error: instruction not allowed in IT block -- `vmov.u8 r0,q0\[0\]'
