.syntax unified
.thumb
vqabs.s8 q0, q1
vqabs.s8 q7, q7
vqabs.s16 q0, q1
vqabs.s16 q7, q7
vqabs.s32 q0, q1
vqabs.s32 q7, q7
vqneg.s8 q0, q1
vqneg.s8 q7, q7
vqneg.s16 q0, q1
vqneg.s16 q7, q7
vqneg.s32 q0, q1
vqneg.s32 q7, q7
vpstete
vqabst.s8 q0, q1
vqabse.s16 q7, q7
vqnegt.s16 q0, q1
vqnege.s32 q7, q7
