.*: Assembler messages:
.*:2: Error: PC-relative access using misaligned offset \(4\)
.*:3: Error: PC-relative access using misaligned offset \(4\)
.*:4: Error: PC-relative access using misaligned symbol \(1c\)
.*:5: Error: PC-relative access using misaligned symbol \(1c\)
.*:6: Error: PC-relative access using misaligned symbol \(1c\)
.*:6: Error: PC-relative access using misaligned offset \(4\)
.*:7: Error: PC-relative access using misaligned symbol \(1c\)
.*:7: Error: PC-relative access using misaligned offset \(4\)
