.*: Assembler messages:
.*:14: Error: invalid operands `jal\.t 0'
.*:16: Error: unrecognized unextended version of MIPS16 opcode `jalx\.t 0'
.*:51: Error: opcode not supported on this processor: mips3 \(mips3\) `restore\.t 128'
.*:52: Error: opcode not supported on this processor: mips3 \(mips3\) `save\.t 128'
.*:111: Error: opcode not supported on this processor: mips3 \(mips3\) `jrc\.t \$16'
.*:112: Error: opcode not supported on this processor: mips3 \(mips3\) `jrc\.t \$31'
.*:113: Error: opcode not supported on this processor: mips3 \(mips3\) `jalrc\.t \$16'
.*:114: Error: opcode not supported on this processor: mips3 \(mips3\) `jalrc\.t \$31,\$16'
.*:115: Error: opcode not supported on this processor: mips3 \(mips3\) `sdbbp\.t 0'
.*:137: Error: opcode not supported on this processor: mips3 \(mips3\) `zeb\.t \$16'
.*:138: Error: opcode not supported on this processor: mips3 \(mips3\) `zeh\.t \$16'
.*:139: Error: opcode not supported on this processor: mips3 \(mips3\) `zew\.t \$16'
.*:140: Error: opcode not supported on this processor: mips3 \(mips3\) `seb\.t \$16'
.*:141: Error: opcode not supported on this processor: mips3 \(mips3\) `seh\.t \$16'
.*:142: Error: opcode not supported on this processor: mips3 \(mips3\) `sew\.t \$16'
