source_sh ${srcdir}/emulparams/cskyelf.sh

unset EMBEDDED
unset ENTRY
COMMONPAGESIZE="CONSTANT (COMMONPAGESIZE)"
GENERATE_SHLIB_SCRIPT=yes
GENERATE_PIE_SCRIPT=yes
GENERATE_SHLIB_SCRIPT=yes
GENERATE_COMBRELOC_SCRIPT=yes
