# name: Reloc against IFUNC symbol in NOTE section
# ld: -shared
# nm: -p

# We do not actually care about the notes at the moment.
# The purpose of this test is to make sure that the link completes successfully.
#pass

