[^:]*: Assembler messages:
[^:]*:5: Error: extra characters '\(R13\)' at the end of absolute operand '&SRC\(R13\)'
[^:]*:5: Error: extra characters '\(R13\)' at the end of absolute operand '&DST\(R13\)'

