[^:]*: Assembler messages:
[^:]*:1: Error: operand mismatch -- `udot v0\.2s,v1\.8b,v2\.4b'
[^:]*:1: Info:    did you mean this\?
[^:]*:1: Info:    	udot v0\.2s, v1\.8b, v2\.8b
[^:]*:1: Info:    other valid variant\(s\):
[^:]*:1: Info:    	udot v0\.4s, v1\.16b, v2\.16b
[^:]*:2: Error: operand mismatch -- `udot v0\.2s,v1\.4b,v2\.8b'
[^:]*:2: Info:    did you mean this\?
[^:]*:2: Info:    	udot v0\.2s, v1\.8b, v2\.8b
[^:]*:2: Info:    other valid variant\(s\):
[^:]*:2: Info:    	udot v0\.4s, v1\.16b, v2\.16b
[^:]*:3: Error: operand mismatch -- `udot v0\.2s,v1\.4b,v2\.4b'
[^:]*:3: Info:    did you mean this\?
[^:]*:3: Info:    	udot v0\.2s, v1\.8b, v2\.8b
[^:]*:3: Info:    other valid variant\(s\):
[^:]*:3: Info:    	udot v0\.4s, v1\.16b, v2\.16b

