.*: Assembler messages:
.*:39: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:41: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:43: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:45: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:47: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:49: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:51: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:53: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:55: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:81: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:83: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:85: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:87: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:89: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:91: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:93: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:95: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:97: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
