#objdump: -d
#name:    
#source:  abs.s


.*:     file format elf32-s12z


Disassembly of section .text:

00000000 <.text>:
   0:	1b 40       	abs d2
   2:	1b 41       	abs d3
   4:	1b 42       	abs d4
   6:	1b 43       	abs d5
   8:	1b 44       	abs d0
   a:	1b 45       	abs d1
   c:	1b 46       	abs d6
   e:	1b 47       	abs d7
