[^:]*: Assembler messages:
[^:]*:11: Warning: NOP inserted here, after an interrupt disable instruction
[^:]*:15: Warning: NOP inserted here, after an interrupt disable instruction
[^:]*:18: Warning: NOP inserted here, after an interrupt disable instruction
[^:]*:21: Warning: NOP inserted here, after an interrupt disable instruction
[^:]*:24: Warning: NOP inserted here, after an interrupt disable instruction
[^:]*:27: Warning: NOP inserted here, after an interrupt disable instruction
[^:]*:30: Warning: NOP inserted here, after an interrupt disable instruction
[^:]*: Warning: NOP inserted after the interrupt state change at the end of the file
