[^:]+: Assembler messages:
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
[^:]+:[0-9]+: Warning: this instruction implies use of ARMv8.1 AdvSIMD.
