.*: Assembler messages:
.*:15: Warning: extended instruction in a branch delay slot
.*:18: Warning: extended instruction in a branch delay slot
.*:21: Warning: macro instruction expanded into multiple instructions in a branch delay slot
.*:24: Warning: macro instruction expanded into multiple instructions in a branch delay slot
