#source: ./dneg.s
#objdump: -dr

.*:     file format .*


Disassembly of section .*:

00000000 <.*>:
   0:	76 90 0c 02                   	dneg	dr0, dr0
   4:	76 90 0c f2                   	dneg	dr0, dr15
   8:	76 90 fc 02                   	dneg	dr15, dr0
   c:	76 90 fc f2                   	dneg	dr15, dr15
