.*: Assembler messages:
.*: Error: unrecognized opcode: `eciwx'
.*: Error: unrecognized opcode: `ecowx'
.*: Error: unrecognized opcode: `mfapidi'
.*: Error: unrecognized opcode: `mfdcr'
.*: Error: unrecognized opcode: `mtdcr'
.*: Error: unrecognized opcode: `tlbia'
.*: Error: unrecognized opcode: `tlbie'
