	exg d0, d1
	exg d1, d1
	exg d2, d1
	exg d3, d1
	exg d4, d1
	exg d5, d1
	exg d6, d1
	exg d7, d1
	exg x, d1
	exg y, d1
	exg cch, d1
	exg ccl, d1
	exg ccw, d1
	exg d6, x
	exg d7, y
	exg x, ccw
	sex y, d7
	exg cch, ccl
