# Test CBCOND instructions
	.text
	cwbe	%o1, %o2,1f
	cwbe	%o1, 2, 1f
	cxbe	%o2, %o3, 1f
	cxbe	%o2, 3, 1f
	cwble	%o3, %o4, 1f
	cwble	%o3, 4, 1f
	cxble	%o4, %o5, 1f
	cxble	%o4, 5, 1f
	cwbl	%o5, %l0, 1f
	cwbl	%o5, 6, 1f
	cxbl	%l0, %l1, 1f
	cxbl	%l0, 7, 1f
	cwbleu	%l1, %l2, 1f
	cwbleu	%l1, 8, 1f
	cxbleu	%l2, %l3, 1f
	cxbleu	%l2, 9, 1f
	cwbcs	%l3, %l4, 1f
	cwbcs	%l3, 10, 1f
	cxbcs	%l4, %l5, 1f
	cxbcs	%l4, 11, 1f
	cwbneg	%l5, %l6, 1f
	cwbneg	%l5, 12, 1f
	cxbneg	%l6, %l7, 1f
	cxbneg	%l6, 13, 1f
	cwbvs	%l7, %i0, 1f
	cwbvs	%l7, 14, 1f
	cxbvs	%i0, %i1, 1f
	cxbvs	%i0, 15, 1f
	cwbne	%i1, %i2, 1f
	cwbne	%i1, 16, 1f
	cxbne	%i2, %i3, 1f
	cxbne	%i2, 17, 1f
	cwbg	%i3, %i4, 1f
	cwbg	%i3, 18, 1f
	cxbg	%i4, %i5, 1f
	cxbg	%i4, 19, 1f
	cwbge	%i5, %o0, 1f
	cwbge	%i5, 20, 1f
	cxbge	%o0, %o1, 1f
	cxbge	%o0, 21, 1f
	cwbgu	%o1, %o2, 1f
	cwbgu	%o1, 22, 1f
	cxbgu	%o2, %o3, 1f
	cxbgu	%o2, 22, 1f
	cwbcc	%o3, %o4, 1f
	cwbcc	%o3, 23, 1f
	cxbcc	%o4, %o5, 1f
	cxbcc	%o4, 24, 1f
	cwbpos	%o5, %l0, 1f
	cwbpos	%o5, 25, 1f
	cxbpos	%l0, %l1, 1f
	cxbpos	%l0, 25, 1f
	cwbvc	%l1, %l2, 1f
	cwbvc	%l1, 26, 1f
	cxbvc	%l2, %l3, 1f
	cxbvc	%l2, 27, 1f
	cwbz	%l3, %l4, 1f
	cwbz	%l3, 28, 1f
	cxbz	%l4, %l5, 1f
	cxbz	%l4, 29, 1f
	cwblu	%l5, %l6, 1f
	cwblu	%l5, 28, 1f
	cxblu	%l6, %l7, 1f
	cxblu	%l6, 29, 1f
	cwbnz	%l7, %o0, 1f
	cwbnz	%l7, 30, 1f
	cxbnz	%o0, %o1, 1f
	cxbnz	%o0, 31, 1f
	cwbgeu	%o1, %o2, 1f
	cwbgeu	%o1, 1, 1f
	cxbgeu	%o2, %o3, 1f
	cxbgeu	%o2, 2, 1f
1:	nop
