.*: Assembler messages:
.*:27: Error: operand value out of range for instruction
.*:30: Error: operand value out of range for instruction
.*:33: Error: operand value out of range for instruction
.*:36: Error: operand value out of range for instruction
