[^:]*: Assembler messages:
[^:]*:3: Error: selected processor does not support `cdp2 [^']*' in (ARM|Thumb) mode
[^:]*:5: Error: selected processor does not support `ldc2 [^.]*' in (ARM|Thumb) mode
[^:]*:6: Error: selected processor does not support `ldc2l [^']*' in (ARM|Thumb) mode
[^:]*:7: Error: selected processor does not support `ldc2 [^']*' in (ARM|Thumb) mode
[^:]*:10: Error: selected processor does not support `stc2 [^']*' in (ARM|Thumb) mode
[^:]*:11: Error: selected processor does not support `stc2l [^']*' in (ARM|Thumb) mode
[^:]*:12: Error: selected processor does not support `stc2 [^']*' in (ARM|Thumb) mode
[^:]*:15: Error: selected processor does not support `mrc2 [^']*' in (ARM|Thumb) mode
[^:]*:16: Error: selected processor does not support `mcr2 [^']*' in (ARM|Thumb) mode
[^:]*:20: Error: selected processor does not support `ldc2 [^']*' in (ARM|Thumb) mode
[^:]*:21: Error: selected processor does not support `stc2 [^']*' in (ARM|Thumb) mode
[^:]*:23: Error: selected processor does not support `ldc2l [^']*' in (ARM|Thumb) mode
[^:]*:24: Error: selected processor does not support `stc2l [^']*' in (ARM|Thumb) mode
