; Test C64x+ S-unit pcrel compact instruction formats
	.text
	nop
	.align 16
	nop
	.align 16
sbs7:
	.short 0x000a
	.short 0x004a
	.short 0x214b
	.short 0x428a
	.short 0x63cb
	.short 0x840a
	.short 0xa54b
	.short 0x868a
	.short 0x77cb
	.short 0x580a
	.short 0x394b
	.short 0x1a8a
	.short 0x3bcb
	.short 0x5c0a
	.word  0xefe00000 | 0x8000
sbu8:
	.short 0xcaca
	.short 0xe7cb
	.short 0xf84a
	.short 0xcacb
	.short 0xd84a
	.short 0xf18b
	.short 0xe84a
	.short 0xd10b
	.short 0xc74a
	.short 0xeacb
	.short 0xd18a
	.short 0xea4b
	.short 0xda4a
	.short 0xd7cb
	.word  0xefe00000 | 0x8000
scs10:
	.short 0x0f1a
	.short 0x1e5b
	.short 0x2d9a
	.short 0x3cdb
	.short 0x4b9a
	.short 0x5a5b
	.short 0x691a
	.short 0x785b
	.short 0x879a
	.short 0x96db
	.short 0xa59a
	.short 0xb45b
	.short 0xc31a
	.short 0xd2db
	.word  0xefe00000 | 0x8000
sbs7c:
 	.short 0x002a
	.short 0x216b
	.short 0x427b
	.short 0x637a
	.short 0x846b
	.short 0xa52a
	.short 0x06bb
	.short 0x07ba
	.short 0x38ab
	.short 0x592a
	.short 0x7afb
	.short 0x9bfa
	.short 0xbceb
	.short 0x0f2a
	.word  0xefe00000 | 0x8000
sbu8c:
	.short 0xc02a
	.short 0xd16b
	.short 0xd27b
	.short 0xd37a
	.short 0xc46b
	.short 0xe52a
	.short 0xe6bb
	.short 0xe7ba
	.short 0xc8ab
	.short 0xf92a
	.short 0xfafb
	.short 0xfbfa
	.short 0xcceb
	.short 0xcf2a
	.word  0xefe00000 | 0x8000
