.*: Assembler messages:
.*:4: Error: ambiguous .* `cvtsi2sd'
.*:5: Error: ambiguous .* `cvtsi2ss'
.*:7: Error: ambiguous .* `vcvtsi2sd'
.*:8: Error: ambiguous .* `vcvtsi2ss'
.*:10: Error: ambiguous .* `vcvtsi2sd'
.*:11: Error: ambiguous .* `vcvtsi2ss'
.*:13: Error: ambiguous .* `vcvtusi2sd'
.*:14: Error: ambiguous .* `vcvtusi2ss'
