.*: Assembler messages:
.*:20: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:24: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:34: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:38: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:52: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:56: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:66: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:70: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
