.*: Assembler messages:
.*:649: Warning: divide by zero
.*:652: Warning: divide by zero
.*:665: Warning: divide by zero
.*:1649: Warning: divide by zero
.*:1652: Warning: divide by zero
.*:1665: Warning: divide by zero
.*:2712: Warning: branch bge is always true
.*:2715: Warning: branch bgeu is always true
.*:2724: Warning: branch bgeu is always true
.*:2799: Warning: branch ble is always true
.*:2814: Warning: branch bleu is always true
.*:2820: Warning: branch bleu is always true
.*:2823: Warning: branch bleu is always true
.*:2922: Warning: branch bgel is always true
.*:2925: Warning: branch bgeul is always true
.*:2934: Warning: branch bgeul is always true
.*:3009: Warning: branch blel is always true
.*:3024: Warning: branch bleul is always true
.*:3030: Warning: branch bleul is always true
.*:3033: Warning: branch bleul is always true
.*:4849: Warning: divide by zero
.*:4852: Warning: divide by zero
.*:4865: Warning: divide by zero
.*:5270: Warning: divide by zero
.*:5280: Warning: divide by zero
.*:5290: Warning: divide by zero
