	.text
	ADD	D1Ar1,D1Ar1,#(_a@TLSGD)
	ADD	D1Ar1,D1Ar1,#(_b@TLSLDM)
	ADDT	D0Re0,D0Re0,#HI(_b@TLSLDO)
	ADD	D0Re0,D0Re0,#LO(_b@TLSLDO)
	GETD	D0.4,[A1LbP+#(_b@TLSIE)]
	MOVT	D0Re0,#HI(_b@TLSIENONPIC)
	ADD	D0Re0,D0Re0,#LO(_b@TLSIENONPIC)
	ADDT	D0Re0,D0Re0,#HI(_b@TLSLE)
	ADD	D0Re0,D0Re0,#LO(_b@TLSLE)
