# Test rdpr
	.text
	rdhpr %hpstate,%g1
	rdhpr %htstate,%g2
	rdhpr %hintp,%g3
	rdhpr %htba,%g4
	rdhpr %hver,%g5
	rdhpr %hstick_offset,%g6
	rdhpr %hstick_enable,%g5
	rdhpr %hstick_cmpr,%g4
	rdhpr %hmcdper,%g6
	rdhpr %hmcddfr,%g5
	rdhpr %hva_mask_nz,%g4
