
.*/tls-local-static:     file format elf32-.*arm.*
architecture: .*, flags 0x[0-9a-f]+:
EXEC_P, HAS_SYMS, D_PAGED
start address 0x[0-9a-f]+

Disassembly of section .text:

[0-9a-f]+ <_start>:
    [0-9a-f]+:	e12fff1e 	bx	lr
    [0-9a-f]+:	00000ff8 	.word	0x00000ff8
