[^:]*: Assembler messages:
[^:]*:22: Error: invalid offset
[^:]*:23: Error: UIMM values >15 are illegal
[^:]*:24: Error: UIMM values >15 are illegal
[^:]*:25: Error: UIMM values >15 are illegal
[^:]*:26: Error: UIMM values >15 are illegal
[^:]*:27: Error: UIMM values >15 are illegal
[^:]*:28: Error: UIMM values >15 are illegal
[^:]*:29: Error: GPR odd is illegal
[^:]*:30: Error: operand out of domain \(7 is not a multiple of 8\)
[^:]*:31: Error: GPR odd is illegal
[^:]*:32: Error: operand out of domain \(7 is not a multiple of 8\)
[^:]*:33: Error: GPR odd is illegal
[^:]*:34: Error: operand out of domain \(7 is not a multiple of 8\)
[^:]*:35: Error: GPR odd is illegal
[^:]*:36: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:37: Error: GPR odd is illegal
[^:]*:38: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:39: Error: GPR odd is illegal
[^:]*:40: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:41: Error: GPR odd is illegal
[^:]*:42: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:43: Error: GPR odd is illegal
[^:]*:44: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:45: Error: GPR odd is illegal
[^:]*:46: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:47: Error: GPR odd is illegal
[^:]*:48: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:49: Error: GPR odd is illegal
[^:]*:50: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:51: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:52: Error: operand out of domain \(3 is not a multiple of 2\)
[^:]*:53: Error: operand out of domain \(3 is not a multiple of 2\)
[^:]*:54: Error: GPR odd is illegal
[^:]*:55: Error: operand out of domain \(7 is not a multiple of 8\)
[^:]*:56: Error: GPR odd is illegal
[^:]*:57: Error: operand out of domain \(7 is not a multiple of 8\)
[^:]*:58: Error: GPR odd is illegal
[^:]*:59: Error: operand out of domain \(7 is not a multiple of 8\)
[^:]*:60: Error: GPR odd is illegal
[^:]*:61: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:62: Error: GPR odd is illegal
[^:]*:63: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:64: Error: operand out of domain \(3 is not a multiple of 2\)
[^:]*:65: Error: operand out of domain \(3 is not a multiple of 2\)
[^:]*:66: Error: operand out of domain \(3 is not a multiple of 2\)
[^:]*:67: Error: operand out of domain \(3 is not a multiple of 2\)
[^:]*:68: Error: operand out of domain \(3 is not a multiple of 2\)
[^:]*:69: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:70: Error: operand out of domain \(3 is not a multiple of 4\)
[^:]*:71: Error: GPR odd is illegal
[^:]*:72: Error: UIMM = 00000 is illegal
[^:]*:73: Error: GPR odd is illegal
[^:]*:74: Error: UIMM = 00000 is illegal
[^:]*:75: Error: GPR odd is illegal
[^:]*:76: Error: UIMM = 00000 is illegal
[^:]*:77: Error: GPR odd is illegal
[^:]*:78: Error: UIMM = 00000 is illegal
[^:]*:79: Error: GPR odd is illegal
[^:]*:80: Error: UIMM = 00000 is illegal
[^:]*:81: Error: GPR odd is illegal
[^:]*:82: Error: UIMM = 00000 is illegal
[^:]*:83: Error: GPR odd is illegal
[^:]*:84: Error: UIMM = 00000 is illegal
[^:]*:85: Error: GPR odd is illegal
[^:]*:86: Error: UIMM = 00000 is illegal
[^:]*:87: Error: GPR odd is illegal
[^:]*:88: Error: UIMM = 00000 is illegal
[^:]*:89: Error: GPR odd is illegal
[^:]*:90: Error: UIMM = 00000 is illegal
[^:]*:91: Error: GPR odd is illegal
[^:]*:92: Error: UIMM = 00000 is illegal
[^:]*:93: Error: UIMM = 00000 is illegal
[^:]*:94: Error: UIMM = 00000 is illegal
[^:]*:95: Error: UIMM = 00000 is illegal
[^:]*:96: Error: UIMM = 00000 is illegal
[^:]*:97: Error: UIMM = 00000 is illegal
[^:]*:98: Error: GPR odd is illegal
[^:]*:99: Error: UIMM = 00000 is illegal
[^:]*:100: Error: GPR odd is illegal
[^:]*:101: Error: UIMM = 00000 is illegal
[^:]*:102: Error: GPR odd is illegal
[^:]*:103: Error: UIMM = 00000 is illegal
[^:]*:104: Error: GPR odd is illegal
[^:]*:105: Error: UIMM = 00000 is illegal
[^:]*:106: Error: UIMM = 00000 is illegal
[^:]*:107: Error: UIMM = 00000 is illegal
[^:]*:108: Error: UIMM = 00000 is illegal
[^:]*:109: Error: UIMM = 00000 is illegal
[^:]*:110: Error: UIMM = 00000 is illegal
[^:]*:111: Error: UIMM = 00000 is illegal
[^:]*:112: Error: UIMM = 00000 is illegal
