# Test ldtxa
	.text
	ldtxa	[%g3] #ASI_TWINX_AIUP, %o2
	ldtxa	[%g3+%g2] #ASI_TWINX_AIUP, %o2
	ldtxa	[%g3] #ASI_TWINX_AIUS, %o2
	ldtxa	[%g3+%g2] #ASI_TWINX_AIUS, %o2
	ldtxa	[%g3] #ASI_TWINX_REAL, %o2
	ldtxa	[%g3+%g2] #ASI_TWINX_REAL, %o2
	ldtxa	[%g3] #ASI_TWINX_N, %o2
	ldtxa	[%g3+%g2] #ASI_TWINX_N, %o2
	ldtxa	[%g3] #ASI_TWINX_AIUP_L, %o2
	ldtxa	[%g3+%g2] #ASI_TWINX_AIUP_L, %o2
	ldtxa	[%g3] #ASI_TWINX_AIUS_L, %o2
	ldtxa	[%g3+%g2] #ASI_TWINX_AIUS_L, %o2
	ldtxa	[%g3] #ASI_TWINX_REAL_L, %o2
	ldtxa	[%g3+%g2] #ASI_TWINX_REAL_L, %o2
	ldtxa	[%g3] #ASI_TWINX_NL, %o2
	ldtxa	[%g3+%g2] #ASI_TWINX_NL, %o2
	ldtxa	[%g3] #ASI_TWINX_P, %o2
	ldtxa	[%g3+%g2] #ASI_TWINX_P, %o2
	ldtxa	[%g3] #ASI_TWINX_S, %o2
	ldtxa	[%g3+%g2] #ASI_TWINX_S, %o2
	ldtxa	[%g3] #ASI_TWINX_PL, %o2
	ldtxa	[%g3+%g2] #ASI_TWINX_PL, %o2
	ldtxa	[%g3] #ASI_TWINX_SL, %o2
	ldtxa	[%g3+%g2] #ASI_TWINX_SL, %o2
