[^:]*: Assembler messages:
[^:]*:10: Error: bad type in SIMD instruction -- `vsri.64 q0,q1,#1'
[^:]*:11: Error: immediate out of range for insert -- `vsri.8 q0,q1,#0'
[^:]*:12: Error: immediate out of range for insert -- `vsri.8 q0,q1,#9'
[^:]*:13: Error: immediate out of range for insert -- `vsri.16 q0,q1,#0'
[^:]*:14: Error: immediate out of range for insert -- `vsri.16 q0,q1,#17'
[^:]*:15: Error: immediate out of range for insert -- `vsri.32 q0,q1,#0'
[^:]*:16: Error: immediate out of range for insert -- `vsri.32 q0,q1,#33'
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:19: Error: syntax error -- `vsrieq.8 q0,q1,#2'
[^:]*:20: Error: syntax error -- `vsrieq.8 q0,q1,#2'
[^:]*:22: Error: syntax error -- `vsrieq.8 q0,q1,#2'
[^:]*:23: Error: vector predicated instruction should be in VPT/VPST block -- `vsrit.8 q0,q1,#2'
[^:]*:25: Error: instruction missing MVE vector predication code -- `vsri.8 q0,q1,#2'
