
Primary GOT:
 Canonical gp value: 0+0a7ff0

 Reserved entries:
 * Address * Access * Initial Purpose
  0+0a0000 -32752\(gp\) 0+ Lazy resolver
  0+0a0008 -32744\(gp\) 8000000000000000 Module pointer \(GNU extension\)

 Local entries:
 * Address * Access * Initial
  0+0a0010 -32736\(gp\) 0+0a2000
  0+0a0018 -32728\(gp\) 0+0430c0
  0+0a0020 -32720\(gp\) 0+0430a0

 Global entries:
 * Address * Access * Initial * Sym\.Val\. * Type * Ndx Name
  0+0a0028 -32712\(gp\) 0+000000 0+000000 FUNC    UND extf2
  0+0a0030 -32704\(gp\) 0+0440a0 0+0440a0 FUNC    UND extf1
  0+0a0038 -32696\(gp\) 0+000000 0+000000 OBJECT  UND extd1
  0+0a0040 -32688\(gp\) 0+000000 0+000000 OBJECT  UND extd4


PLT GOT:

 Reserved entries:
 * Address * Initial * Purpose
  0+081000 0+ PLT lazy resolver
  0+081008 0+ Module pointer

 Entries:
 * Address * Initial * Sym.Val. * Type * Ndx Name
  0+081010 0+043080 0+0430a0 FUNC    UND extf4
  0+081018 0+043080 0+000000 FUNC    UND extf5
  0+081020 0+043080 0+000000 FUNC    UND extf3
