        .text
vsx3:
	lxvx         34,6,25
	lxvx         20,0,10
	lxvl         20,24,10
	lxvl         54,0,29
	lxvll        24,20,19
	lxvll        34,0,14
	mfvsrld      2,22
	lxvwsx       58,26,25
	lxvwsx       55,0,29
	stxvx        14,21,4
	stxvx        30,0,22
	stxvl        0,26,4
	stxvl        37,0,22
	mtvsrws      24,10
	stxvll       30,21,15
	stxvll       39,0,14
	mtvsrdd      12,6,5
	mtvsrdd      38,0,21
	lxsibzx      59,28,6
	lxsibzx      30,0,8
	lxvh8x       42,23,17
	lxvh8x       36,0,5
	lxsihzx      12,9,11
	lxsihzx      49,0,13
	lxvb16x      37,3,19
	lxvb16x      0,0,30
	stxsibx      2,30,6
	stxsibx      12,0,13
	stxvh8x      16,29,8
	stxvh8x      55,0,10
	stxsihx      34,2,23
	stxsihx      60,0,23
	stxvb16x     23,14,12
	stxvb16x     19,0,5
	lxsd         24,0(0)
	lxsd         15,16(21)
	lxssp        6,0(0)
	lxssp        23,16(9)
	xscmpeqdp    18,51,33
	xscmpgtdp    2,26,34
	xscmpgedp    5,26,20
	xxperm       44,10,43
	xxpermr      41,20,5
	xscmpexpdp   4,18,55
	xxextractuw  23,37,3
	xxspltib     54,235
	xxinsertw    15,30,4
	xsmaxcdp     12,11,7
	xsmincdp     32,25,24
	xsmaxjdp     25,53,12
	xststdcsp    2,36,127
	xsminjdp     32,21,45
	xsxexpdp     17,50
	xsxsigdp     7,40
	xscvhpdp     54,34
	xscvdphp     58,54
	xststdcdp    0,38,127
	xvtstdcsp    56,53,127
	xviexpsp     54,20,52
	xsiexpdp     57,28,29
	xvxexpdp     1,20
	xvxsigdp     54,59
	xxbrh        18,37
	xvxexpsp     14,1
	xvxsigsp     52,13
	xxbrw        19,5
	xxbrd        51,55
	xvcvhpsp     35,17
	xvcvsphp     15,45
	xxbrq        17,31
	xvtstdcdp    16,12,127
	xviexpdp     27,9,8
	lxv          4,0(0)
	lxv          40,16(20)
	stxv         50,0(0)
	stxv         8,16(16)
	stxsd        3,0(0)
	stxsd        17,16(2)
	stxssp       13,0(0)
	stxssp       17,16(13)
	xsaddqp      8,10,18
	xsaddqpo     5,1,29
	xsrqpi       0,12,18,3
	xsrqpix      1,31,19,0
	xsmulqp      14,1,6
	xsmulqpo     17,7,27
	xsrqpxp      0,4,11,0
	xscpsgnqp    29,23,28
	xscmpoqp     7,13,27
	xscmpexpqp   5,21,6
	xsmaddqp     2,19,4
	xsmaddqpo    30,7,16
	xsmsubqp     21,30,15
	xsmsubqpo    12,17,30
	xsnmaddqp    6,30,12
	xsnmaddqpo   12,22,12
	xsnmsubqp    10,29,27
	xsnmsubqpo   29,29,13
	xssubqp      19,27,4
	xssubqpo     13,8,1
	xsdivqp      8,3,27
	xsdivqpo     24,20,27
	xscmpuqp     7,14,4
	xststdcqp    4,2,127
	xsabsqp      31,22
	xsxexpqp     25,3
	xsnabsqp     10,28
	xsnegqp      19,31
	xsxsigqp     11,13
	xssqrtqp     13,14
	xssqrtqpo    1,27
	xscvqpuwz    3,7
	xscvudqp     20,18
	xscvqpswz    29,29
	xscvsdqp     2,28
	xscvqpudz    23,4
	xscvqpdp     3,20
	xscvqpdpo    1,3
	xscvdpqp     19,12
	xscvqpsdz    13,4
	xsiexpqp     7,24,7
