#readelf: -wl

Raw dump of debug contents of section \.debug_line:

  Offset:                      0x0
  Length:                      51
  DWARF Version:               3
  Prologue Length:             26
  Minimum Instruction Length:  1
  Initial value of 'is_stmt':  1
  Line Base:                   -5
  Line Range:                  14
  Opcode Base:                 13

 Opcodes:
  Opcode 1 has 0 args
  Opcode 2 has 1 arg
  Opcode 3 has 1 arg
  Opcode 4 has 1 arg
  Opcode 5 has 1 arg
  Opcode 6 has 0 args
  Opcode 7 has 0 args
  Opcode 8 has 0 args
  Opcode 9 has 1 arg
  Opcode 10 has 0 args
  Opcode 11 has 0 args
  Opcode 12 has 1 arg

 The Directory Table is empty\.

 The File Name Table \(offset 0x.*\):
  Entry	Dir	Time	Size	Name
  1	0	0	0	x\.c

 Line Number Statements:
  \[0x.*\]  Extended opcode 2: set Address to 0x1
  \[0x.*\]  Special opcode 8: advance Address by 0 to 0x1 and Line by 3 to 4
  \[0x.*\]  Special opcode 216: advance Address by 15 to 0x10 and Line by 1 to 5
  \[0x.*\]  Special opcode 228: advance Address by 16 to 0x20 and Line by -1 to 4
  \[0x.*\]  Advance PC by 16 to 0x30
  \[0x.*\]  Extended opcode 1: End of Sequence


