[^:]*: Assembler messages:
[^:]*:4: Warning: ARMv8.2 scalar fp16 instruction cannot be conditional, the behaviour is UNPREDICTABLE
[^:]*:5: Warning: ARMv8.2 scalar fp16 instruction cannot be conditional, the behaviour is UNPREDICTABLE
[^:]*:7: Warning: ARMv8.2 scalar fp16 instruction cannot be conditional, the behaviour is UNPREDICTABLE
[^:]*:8: Warning: ARMv8.2 scalar fp16 instruction cannot be conditional, the behaviour is UNPREDICTABLE
[^:]*:10: Error: selected FPU does not support instruction -- `vaddl.s8 q0,d1,d2'
[^:]*:11: Error: selected FPU does not support instruction -- `vsubl.s8 q0,d1,d2'
