.*: Assembler messages:
.*:3: Error: `fp=64' used with a 32-bit fpu
.*:3: Warning: float register should be even, was 1
.*:3: Warning: float register should be even, was 1
.*:3: Warning: float register should be even, was 1
