[^:]*: Assembler messages:
[^:]*:1: Error: file was compiled for the 430X ISA but the 430 ISA is selected
[^:]*:4: Error: file was compiled assuming all data will be in the lower memory region, but the upper region is in use
