.*smc-bad.s: Assembler messages:
.*smc-bad.s:2: Error: immediate too large \(bigger than 0xF\) -- `smc #0xfefe'
.*smc-bad.s:3: Error: immediate too large \(bigger than 0xF\) -- `smc #0x12'
.*smc-bad.s:4: Error: immediate too large \(bigger than 0xF\) -- `smc 123'
.*smc-bad.s:7: Error: immediate too large \(bigger than 0xF\) -- `smc #0xdfd'
.*smc-bad.s:8: Error: immediate too large \(bigger than 0xF\) -- `smc #0x43'
.*smc-bad.s:9: Error: immediate too large \(bigger than 0xF\) -- `smc 4343343'
.*smc-bad.s:14: Error: immediate too large \(bigger than 0xF\) -- `smc #0x6951'
