.*: Assembler messages:
.*:5: Error: number \(0x9000000080000000\) larger than 32 bits
.*:7: Warning: the `virt' extension requires MIPS64 revision 2 or greater
.*:10: Error: number \(0x9000000080000000\) larger than 32 bits
.*:13: Error: number \(0x9000000080000000\) larger than 32 bits
