#objdump: -d
#name:    
#source:  com-opr.s


.*:     file format elf32-s12z


Disassembly of section .text:

00000000 <.text>:
   0:	cc df       	com.b \[d7,y\]
   2:	cd fe 00 1f 	com.w \[8134\]
   6:	c6 
   7:	cf ae       	com.l \(d6,s\)
