.*: Assembler messages:
.*:25: Error: operand value out of range for instruction
.*:26: Error: operand value out of range for instruction
.*:27: Error: operand value out of range for instruction
.*:28: Error: operand value out of range for instruction
