
tmpdir/fdpic-main.*:     file format elf32-(little|big)arm

DYNAMIC RELOCATION RECORDS
OFFSET   TYPE              VALUE 
.* R_ARM_FUNCDESC    my_shared_func1
.* R_ARM_FUNCDESC    my_shared_func1
.* R_ARM_FUNCDESC_VALUE  my_shared_func1
.* R_ARM_FUNCDESC_VALUE  my_shared_func2


