[^:]*: Assembler messages:
[^:]*:10: Error: bad type in SIMD instruction -- `vmaxnma.f64 q0,q1'
[^:]*:11: Error: bad type in SIMD instruction -- `vmaxnma.i16 q0,q1'
[^:]*:12: Error: bad type in SIMD instruction -- `vminnma.f64 q0,q1'
[^:]*:13: Error: bad type in SIMD instruction -- `vminnma.i16 q0,q1'
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:14: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:15: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:17: Error: syntax error -- `vmaxnmaeq.f32 q0,q1'
[^:]*:18: Error: syntax error -- `vmaxnmaeq.f32 q0,q1'
[^:]*:20: Error: syntax error -- `vmaxnmaeq.f32 q0,q1'
[^:]*:21: Error: vector predicated instruction should be in VPT/VPST block -- `vmaxnmat.f32 q0,q1'
[^:]*:23: Error: instruction missing MVE vector predication code -- `vmaxnma.f32 q0,q1'
[^:]*:25: Error: syntax error -- `vminnmaeq.f32 q0,q1'
[^:]*:26: Error: syntax error -- `vminnmaeq.f32 q0,q1'
[^:]*:28: Error: syntax error -- `vminnmaeq.f32 q0,q1'
[^:]*:29: Error: vector predicated instruction should be in VPT/VPST block -- `vminnmat.f32 q0,q1'
[^:]*:31: Error: instruction missing MVE vector predication code -- `vminnma.f32 q0,q1'
