.*: Assembler messages:
.*:6: Error: bad expression
.*:6: Error: invalid operands `addiu \$4,\$28,%dtprel\(tlsvar\)'
.*:7: Error: bad expression
.*:7: Error: invalid operands `addiu \$4,\$28,%tprel\(tlsvar\)'
.*:8: Error: bad expression
.*:8: Error: found 'g', expected: '\)'
.*:8: Error: invalid operands `addiu \$4,\$28,%lo\(%gottprel\(tlsvar\)\)'
.*:9: Error: bad expression
.*:9: Error: found 'g', expected: '\)'
.*:9: Error: invalid operands `addiu \$4,\$28,%hi\(%gottprel\(tlsvar\)\)'
