[^:]*: Assembler messages:
[^:]*:11: Warning: a NOP might also be needed here, after the instruction that changed interrupt state
[^:]*:16: Warning: a NOP might also be needed here, after the instruction that changed interrupt state
