	.text
	.psize 0
movsx:
	movsx	%al, %cl
	movsx	%ax, %cl
	movsx	%eax, %cl
	movsx	%rax, %cl

	movsx	%al, %cx
	movsx	%ax, %cx
	movsx	%eax, %cx
	movsx	%rax, %cx

	movsx	%al, %ecx
	movsx	%ax, %ecx
	movsx	%eax, %ecx
	movsx	%rax, %ecx

	movsx	%al, %rcx
	movsx	%ax, %rcx
	movsx	%eax, %rcx
	movsx	%rax, %rcx

	movsxb	%al, %cl
	movsxb	%ax, %cl
	movsxb	%eax, %cl
	movsxb	%rax, %cl

	movsxb	%al, %cx
	movsxb	%ax, %cx
	movsxb	%eax, %cx
	movsxb	%rax, %cx

	movsxb	%al, %ecx
	movsxb	%ax, %ecx
	movsxb	%eax, %ecx
	movsxb	%rax, %ecx

	movsxb	%al, %rcx
	movsxb	%ax, %rcx
	movsxb	%eax, %rcx
	movsxb	%rax, %rcx

	movsxw	%al, %cl
	movsxw	%ax, %cl
	movsxw	%eax, %cl
	movsxw	%rax, %cl

	movsxw	%al, %cx
	movsxw	%ax, %cx
	movsxw	%eax, %cx
	movsxw	%rax, %cx

	movsxw	%al, %ecx
	movsxw	%ax, %ecx
	movsxw	%eax, %ecx
	movsxw	%rax, %ecx

	movsxw	%al, %rcx
	movsxw	%ax, %rcx
	movsxw	%eax, %rcx
	movsxw	%rax, %rcx

	movsxl	%al, %cl
	movsxl	%ax, %cl
	movsxl	%eax, %cl
	movsxl	%rax, %cl

	movsxl	%al, %cx
	movsxl	%ax, %cx
	movsxl	%eax, %cx
	movsxl	%rax, %cx

	movsxl	%al, %ecx
	movsxl	%ax, %ecx
	movsxl	%eax, %ecx
	movsxl	%rax, %ecx

	movsxl	%al, %rcx
	movsxl	%ax, %rcx
	movsxl	%eax, %rcx
	movsxl	%rax, %rcx

	movsxd	%al, %cl
	movsxd	%ax, %cl
	movsxd	%eax, %cl
	movsxd	%rax, %cl

	movsxd	%al, %cx
	movsxd	%ax, %cx
	movsxd	%eax, %cx
	movsxd	%rax, %cx

	movsxd	%al, %ecx
	movsxd	%ax, %ecx
	movsxd	%eax, %ecx
	movsxd	%rax, %ecx

	movsxd	%al, %rcx
	movsxd	%ax, %rcx
	movsxd	%eax, %rcx
	movsxd	%rax, %rcx

	movsb	%al, %cl
	movsb	%ax, %cl
	movsb	%eax, %cl
	movsb	%rax, %cl

	movsb	%al, %cx
	movsb	%ax, %cx
	movsb	%eax, %cx
	movsb	%rax, %cx

	movsb	%al, %ecx
	movsb	%ax, %ecx
	movsb	%eax, %ecx
	movsb	%rax, %ecx

	movsb	%al, %rcx
	movsb	%ax, %rcx
	movsb	%eax, %rcx
	movsb	%rax, %rcx

	movsbw	%al, %cl
	movsbw	%ax, %cl
	movsbw	%eax, %cl
	movsbw	%rax, %cl

	movsbw	%al, %cx
	movsbw	%ax, %cx
	movsbw	%eax, %cx
	movsbw	%rax, %cx

	movsbw	%al, %ecx
	movsbw	%ax, %ecx
	movsbw	%eax, %ecx
	movsbw	%rax, %ecx

	movsbw	%al, %rcx
	movsbw	%ax, %rcx
	movsbw	%eax, %rcx
	movsbw	%rax, %rcx

	movsbl	%al, %cl
	movsbl	%ax, %cl
	movsbl	%eax, %cl
	movsbl	%rax, %cl

	movsbl	%al, %cx
	movsbl	%ax, %cx
	movsbl	%eax, %cx
	movsbl	%rax, %cx

	movsbl	%al, %ecx
	movsbl	%ax, %ecx
	movsbl	%eax, %ecx
	movsbl	%rax, %ecx

	movsbl	%al, %rcx
	movsbl	%ax, %rcx
	movsbl	%eax, %rcx
	movsbl	%rax, %rcx

	movsbq	%al, %cl
	movsbq	%ax, %cl
	movsbq	%eax, %cl
	movsbq	%rax, %cl

	movsbq	%al, %cx
	movsbq	%ax, %cx
	movsbq	%eax, %cx
	movsbq	%rax, %cx

	movsbq	%al, %ecx
	movsbq	%ax, %ecx
	movsbq	%eax, %ecx
	movsbq	%rax, %ecx

	movsbq	%al, %rcx
	movsbq	%ax, %rcx
	movsbq	%eax, %rcx
	movsbq	%rax, %rcx

	movsw	%al, %cl
	movsw	%ax, %cl
	movsw	%eax, %cl
	movsw	%rax, %cl

	movsw	%al, %cx
	movsw	%ax, %cx
	movsw	%eax, %cx
	movsw	%rax, %cx

	movsw	%al, %ecx
	movsw	%ax, %ecx
	movsw	%eax, %ecx
	movsw	%rax, %ecx

	movsw	%al, %rcx
	movsw	%ax, %rcx
	movsw	%eax, %rcx
	movsw	%rax, %rcx

	movswl	%al, %cl
	movswl	%ax, %cl
	movswl	%eax, %cl
	movswl	%rax, %cl

	movswl	%al, %cx
	movswl	%ax, %cx
	movswl	%eax, %cx
	movswl	%rax, %cx

	movswl	%al, %ecx
	movswl	%ax, %ecx
	movswl	%eax, %ecx
	movswl	%rax, %ecx

	movswl	%al, %rcx
	movswl	%ax, %rcx
	movswl	%eax, %rcx
	movswl	%rax, %rcx

	movswq	%al, %cl
	movswq	%ax, %cl
	movswq	%eax, %cl
	movswq	%rax, %cl

	movswq	%al, %cx
	movswq	%ax, %cx
	movswq	%eax, %cx
	movswq	%rax, %cx

	movswq	%al, %ecx
	movswq	%ax, %ecx
	movswq	%eax, %ecx
	movswq	%rax, %ecx

	movswq	%al, %rcx
	movswq	%ax, %rcx
	movswq	%eax, %rcx
	movswq	%rax, %rcx

movzx:
	movzx	%al, %cl
	movzx	%ax, %cl
	movzx	%eax, %cl
	movzx	%rax, %cl

	movzx	%al, %cx
	movzx	%ax, %cx
	movzx	%eax, %cx
	movzx	%rax, %cx

	movzx	%al, %ecx
	movzx	%ax, %ecx
	movzx	%eax, %ecx
	movzx	%rax, %ecx

	movzx	%al, %rcx
	movzx	%ax, %rcx
	movzx	%eax, %rcx
	movzx	%rax, %rcx

	movzxb	%al, %cl
	movzxb	%ax, %cl
	movzxb	%eax, %cl
	movzxb	%rax, %cl

	movzxb	%al, %cx
	movzxb	%ax, %cx
	movzxb	%eax, %cx
	movzxb	%rax, %cx

	movzxb	%al, %ecx
	movzxb	%ax, %ecx
	movzxb	%eax, %ecx
	movzxb	%rax, %ecx

	movzxb	%al, %rcx
	movzxb	%ax, %rcx
	movzxb	%eax, %rcx
	movzxb	%rax, %rcx

	movzxw	%al, %cl
	movzxw	%ax, %cl
	movzxw	%eax, %cl
	movzxw	%rax, %cl

	movzxw	%al, %cx
	movzxw	%ax, %cx
	movzxw	%eax, %cx
	movzxw	%rax, %cx

	movzxw	%al, %ecx
	movzxw	%ax, %ecx
	movzxw	%eax, %ecx
	movzxw	%rax, %ecx

	movzxw	%al, %rcx
	movzxw	%ax, %rcx
	movzxw	%eax, %rcx
	movzxw	%rax, %rcx

	movzxl	%al, %cl
	movzxl	%ax, %cl
	movzxl	%eax, %cl
	movzxl	%rax, %cl

	movzxl	%al, %cx
	movzxl	%ax, %cx
	movzxl	%eax, %cx
	movzxl	%rax, %cx

	movzxl	%al, %ecx
	movzxl	%ax, %ecx
	movzxl	%eax, %ecx
	movzxl	%rax, %ecx

	movzxl	%al, %rcx
	movzxl	%ax, %rcx
	movzxl	%eax, %rcx
	movzxl	%rax, %rcx

	movzxd	%al, %cl
	movzxd	%ax, %cl
	movzxd	%eax, %cl
	movzxd	%rax, %cl

	movzxd	%al, %cx
	movzxd	%ax, %cx
	movzxd	%eax, %cx
	movzxd	%rax, %cx

	movzxd	%al, %ecx
	movzxd	%ax, %ecx
	movzxd	%eax, %ecx
	movzxd	%rax, %ecx

	movzxd	%al, %rcx
	movzxd	%ax, %rcx
	movzxd	%eax, %rcx
	movzxd	%rax, %rcx

	movzb	%al, %cl
	movzb	%ax, %cl
	movzb	%eax, %cl
	movzb	%rax, %cl

	movzb	%al, %cx
	movzb	%ax, %cx
	movzb	%eax, %cx
	movzb	%rax, %cx

	movzb	%al, %ecx
	movzb	%ax, %ecx
	movzb	%eax, %ecx
	movzb	%rax, %ecx

	movzb	%al, %rcx
	movzb	%ax, %rcx
	movzb	%eax, %rcx
	movzb	%rax, %rcx

	movzbw	%al, %cl
	movzbw	%ax, %cl
	movzbw	%eax, %cl
	movzbw	%rax, %cl

	movzbw	%al, %cx
	movzbw	%ax, %cx
	movzbw	%eax, %cx
	movzbw	%rax, %cx

	movzbw	%al, %ecx
	movzbw	%ax, %ecx
	movzbw	%eax, %ecx
	movzbw	%rax, %ecx

	movzbw	%al, %rcx
	movzbw	%ax, %rcx
	movzbw	%eax, %rcx
	movzbw	%rax, %rcx

	movzbl	%al, %cl
	movzbl	%ax, %cl
	movzbl	%eax, %cl
	movzbl	%rax, %cl

	movzbl	%al, %cx
	movzbl	%ax, %cx
	movzbl	%eax, %cx
	movzbl	%rax, %cx

	movzbl	%al, %ecx
	movzbl	%ax, %ecx
	movzbl	%eax, %ecx
	movzbl	%rax, %ecx

	movzbl	%al, %rcx
	movzbl	%ax, %rcx
	movzbl	%eax, %rcx
	movzbl	%rax, %rcx

	movzbq	%al, %cl
	movzbq	%ax, %cl
	movzbq	%eax, %cl
	movzbq	%rax, %cl

	movzbq	%al, %cx
	movzbq	%ax, %cx
	movzbq	%eax, %cx
	movzbq	%rax, %cx

	movzbq	%al, %ecx
	movzbq	%ax, %ecx
	movzbq	%eax, %ecx
	movzbq	%rax, %ecx

	movzbq	%al, %rcx
	movzbq	%ax, %rcx
	movzbq	%eax, %rcx
	movzbq	%rax, %rcx

	movzw	%al, %cl
	movzw	%ax, %cl
	movzw	%eax, %cl
	movzw	%rax, %cl

	movzw	%al, %cx
	movzw	%ax, %cx
	movzw	%eax, %cx
	movzw	%rax, %cx

	movzw	%al, %ecx
	movzw	%ax, %ecx
	movzw	%eax, %ecx
	movzw	%rax, %ecx

	movzw	%al, %rcx
	movzw	%ax, %rcx
	movzw	%eax, %rcx
	movzw	%rax, %rcx

	movzwl	%al, %cl
	movzwl	%ax, %cl
	movzwl	%eax, %cl
	movzwl	%rax, %cl

	movzwl	%al, %cx
	movzwl	%ax, %cx
	movzwl	%eax, %cx
	movzwl	%rax, %cx

	movzwl	%al, %ecx
	movzwl	%ax, %ecx
	movzwl	%eax, %ecx
	movzwl	%rax, %ecx

	movzwl	%al, %rcx
	movzwl	%ax, %rcx
	movzwl	%eax, %rcx
	movzwl	%rax, %rcx

	movzwq	%al, %cl
	movzwq	%ax, %cl
	movzwq	%eax, %cl
	movzwq	%rax, %cl

	movzwq	%al, %cx
	movzwq	%ax, %cx
	movzwq	%eax, %cx
	movzwq	%rax, %cx

	movzwq	%al, %ecx
	movzwq	%ax, %ecx
	movzwq	%eax, %ecx
	movzwq	%rax, %ecx

	movzwq	%al, %rcx
	movzwq	%ax, %rcx
	movzwq	%eax, %rcx
	movzwq	%rax, %rcx

	.p2align 4
