[^:]*: Assembler messages:
[^:]*:8: Error: selected processor does not support `vfms.f32 s0,s1,s2' in ARM mode
[^:]*:11: Error: selected processor does not support `vfms.f32 s0,s1,s2' in ARM mode
[^:]*:17: Error: selected processor does not support `vfms.f32 s0,s1,s2' in ARM mode
