.byte 0x67; bndmk  (%rax),%bnd1
.byte 0x67; bndmk  0x3(%rcx,%rbx,1),%bnd1
.byte 0x67; bndmov (%r8),%bnd1
.byte 0x67; bndmov 0x3(%r9,%rdx,1),%bnd1
.byte 0x67; bndmov %bnd1,(%rax)
.byte 0x67; bndmov %bnd1,0x3(%rcx,%rax,1)
.byte 0x67; bndcl  (%rcx),%bnd1
.byte 0x67; bndcl  0x3(%rcx,%rax,1),%bnd1
.byte 0x67; bndcu  (%rcx),%bnd1
.byte 0x67; bndcu  0x3(%rcx,%rax,1),%bnd1
.byte 0x67; bndcn  (%rcx),%bnd1
.byte 0x67; bndcn  0x3(%rcx,%rax,1),%bnd1
.byte 0x67; bndstx %bnd0,0x3(%rax,%rbx,1)
.byte 0x67; bndstx %bnd2,0x3(%rbx)
.byte 0x67; bndldx 0x3(%rax,%rbx,1),%bnd0
.byte 0x67; bndldx 0x3(%rbx),%bnd2
.byte 0x67; bndmk  (%rax),%bnd1
.byte 0x67; bndmk  0x3(%rdx,%rax,1),%bnd1
.byte 0x67; bndmov (%rax),%bnd1
.byte 0x67; bndmov 0x3(%rdx,%rax,1),%bnd1
.byte 0x67; bndmov %bnd1,(%rax)
.byte 0x67; bndmov %bnd1,0x3(%rdx,%rax,1)
.byte 0x67; bndcl  (%rax),%bnd1
.byte 0x67; bndcl  0x3(%rdx,%rax,1),%bnd1
.byte 0x67; bndcu  (%rax),%bnd1
.byte 0x67; bndcu  0x3(%rdx,%rax,1),%bnd1
.byte 0x67; bndcn  (%rax),%bnd1
.byte 0x67; bndcn  0x3(%rdx,%rax,1),%bnd1
.byte 0x67; bndstx %bnd0,0x3(%rax,%rbx,1)
.byte 0x67; bndstx %bnd2,0x3(,%rbx,1)
.byte 0x67; bndldx 0x3(%rax,%rbx,1),%bnd0
.byte 0x67; bndldx 0x3(,%rbx,1),%bnd2
