.*: Assembler messages:
.*:6: Error: invalid register operand size for `enqcmd'
.*:7: Error: invalid register operand size for `enqcmd'
.*:8: Error: invalid register operand size for `enqcmds'
.*:9: Error: invalid register operand size for `enqcmds'
.*:12: Error: invalid register operand size for `enqcmd'
.*:13: Error: invalid register operand size for `enqcmd'
.*:14: Error: invalid register operand size for `enqcmds'
.*:15: Error: invalid register operand size for `enqcmds'

