[^:]*: Assembler messages:
[^:]*:9: Error: branch out of range
[^:]*:5: Error: branch out of range
[^:]*:8: Error: branch out of range
[^:]*:11: Error: branch out of range
[^:]*:15: Error: branch out of range
