.*: Assembler messages:
.*:3: Error: operand 3 must be scalar `sll.ob \$f2,\$f4,\$f6'
.*:7: Error: operand 3 must be scalar `srl.ob \$f2,\$f4,\$f6'
.*:10: Error: operand 2 must be an immediate `rzu.ob \$f2,\$f6\[1\]'
.*:11: Error: operand 2 must be an immediate `rzu.ob \$f2,\$f6'
.*:14: Error: invalid operands `add.ob \$v2,\$f4,\$f6'
.*:15: Error: invalid operands `add.ob \$f2,\$v4,\$f6'
.*:16: Error: invalid operands `add.ob \$f2,\$f4,\$v6'
.*:17: Error: invalid operands `add.ob \$v2,\$v4,\$v6'
.*:20: Error: invalid operands `add.ob \$v2,\$f4,\$f6\[1\]'
.*:21: Error: invalid operands `add.ob \$f2,\$v4,\$f6\[1\]'
.*:22: Error: invalid operands `add.ob \$f2,\$f4,\$v6\[1\]'
.*:23: Error: invalid operands `add.ob \$v2,\$v4,\$v6\[1\]'
.*:25: Error: vector element must be constant `add.ob \$f2,\$f4,\$f6\[foo\]'
.*:26: Error: missing `\]' `add.ob \$f2,\$f4,\$f6\[1}'
