[^:]*: Assembler messages:
[^:]*:6: Warning: index register overlaps transfer register
[^:]*:7: Warning: index register overlaps transfer register
[^:]*:8: Warning: source register same as write-back base
[^:]*:9: Warning: base register written back, and overlaps second transfer register
[^:]*:13: Warning: source register same as write-back base
[^:]*:14: Warning: base register written back, and overlaps second transfer register
