
Attribute Section: gnu
File Attributes
  Tag_GNU_MIPS_ABI_FP: Hard float \(32-bit CPU, 64-bit FPU\)

Primary GOT:
 Canonical gp value: 000183f0

 Reserved entries:
   Address     Access  Initial Purpose
  00010400 -32752\(gp\) 00000000 Lazy resolver
  00010404 -32748\(gp\) 80000000 Module pointer \(GNU extension\)

 Local entries:
   Address     Access  Initial
  00010408 -32744\(gp\) 00010000

 Global entries:
   Address     Access  Initial Sym\.Val\. Type    Ndx Name
  0001040c -32740\(gp\) 00000800 00000800 FUNC      6 foo
  00010410 -32736\(gp\) 00000c00 00000c00 FUNC    UND ext
