# check valid common choices.

	.comm noalign, 1
	.comm alignis0, 2, 0
.comm column1 , 3,1
 .comm	onespace, 4,2
	.comm	tabbed	,	5	,	3	
	.comm nowhtspace,6,4
	.comm bar, 7, 8
	.comm maxalign, 8, 15
	.comm hugearray, 1234567,2

