.*: Assembler messages:
.*:4: Error: invalid unextended operand value
.*:5: Error: invalid unextended operand value
.*:6: Error: invalid unextended operand value
.*:7: Error: invalid unextended operand value
.*:8: Error: invalid unextended operand value
