.*warn_nobreak.s: Assembler messages:
.*warn_nobreak.s:2: Warning: The debugger will corrupt sstatus/ba \(r30\).
If you don't need to debug this code use .set nobreak to turn off this warning.
.*warn_nobreak.s:3: Warning: The debugger will corrupt bt \(r25\).
If you don't need to debug this code use .set nobreak to turn off this warning.
.*warn_nobreak.s:11: Warning: The debugger will corrupt sstatus/ba \(r30\).
If you don't need to debug this code use .set nobreak to turn off this warning.
.*warn_nobreak.s:12: Warning: The debugger will corrupt bt \(r25\).
If you don't need to debug this code use .set nobreak to turn off this warning.
