[^:]*: Assembler messages:
[^:]*:[0-9]+: Error: selected processor does not support PSTATE field name 'ssbs'
[^:]*:[0-9]+: Error: selected processor does not support PSTATE field name 'ssbs'
[^:]*:[0-9]+: Error: selected processor does not support PSTATE field name 'ssbs'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'ssbs'
[^:]*:[0-9]+: Error: selected processor does not support system register name 'ssbs'
