.*: Assembler messages:
.*:50: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:52: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:54: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:56: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:58: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:66: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:68: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:70: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:72: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:106: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:108: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:110: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:112: Error: cannot encode misaligned addend in the relocatable field \(0x1\)
.*:114: Error: cannot encode misaligned addend in the relocatable field \(0x2\)
.*:122: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:124: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:126: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
.*:128: Error: cannot encode misaligned addend in the relocatable field \(0x3\)
