.*pr19910-2.s: Assembler messages:
.*pr19910-2.s:2: Error: Expression inside %hi could not be parsed
.*pr19910-2.s:5: Error: found 'V', expected: '\)'
.*pr19910-2.s:5: Error: Expression inside %lo could not be parsed
