#source: pr23900-2.s
#ld:
#readelf: --notes --wide
#target: *-*-linux* *-*-gnu* *-*-nacl*

#...
Displaying notes found in: \.note
[ 	]+Owner[ 	]+Data size[ 	]+Description
[ 	]+GNU[ 	]+0x0+..[ 	]+NT_GNU_PROPERTY_TYPE_0[ 	]+Properties: no copy on protected 
