[^:]*: Assembler messages:
[^:]*:3: Error: invalid neon suffix for non neon instruction
[^:]*:4: Error: invalid neon suffix for non neon instruction
[^:]*:5: Error: invalid neon suffix for non neon instruction
[^:]*:6: Error: invalid instruction shape -- `vcvt.f64.s32 d0,s0,#11'
[^:]*:9: Error: invalid neon suffix for non neon instruction
[^:]*:10: Error: invalid neon suffix for non neon instruction
[^:]*:11: Error: invalid neon suffix for non neon instruction
[^:]*:12: Error: invalid instruction shape -- `vcvt.f64.s32 d0,s0,#11'
