#source: ./mvtaclo.s
#objdump: -dr

.*:     file format .*


Disassembly of section \.text:

00000000 <\.text>:
   0:	fd 17 10                      	mvtaclo	r0, a0
   3:	fd 17 1f                      	mvtaclo	r15, a0
   6:	fd 17 10                      	mvtaclo	r0, a0
   9:	fd 17 1f                      	mvtaclo	r15, a0
   c:	fd 17 90                      	mvtaclo	r0, a1
   f:	fd 17 9f                      	mvtaclo	r15, a1
