#as: -march-attr -mpriv-spec=1.9.1
#readelf: -A
#source: attribute-11.s
Attribute Section: riscv
File Attributes
  Tag_RISCV_arch: [a-zA-Z0-9_\"].*
  Tag_RISCV_priv_spec: 1
  Tag_RISCV_priv_spec_minor: 9
  Tag_RISCV_priv_spec_revision: 1
