.*warning: no input section rule matches .lower.text in linker script
.*warning: no input section rule matches .lower.data in linker script
.*warning: no input section rule matches .lower.bss in linker script
.*warning: no input section rule matches .lower.rodata in linker script
