[^:]*: Assembler messages:
[^:]*:1: Error: unsupported section id: 0x100000000
[^:]*:3: Error: junk at end of line, first unrecognized character is `f'
[^:]*:5: Error: junk at end of line, first unrecognized character is `,'
