[^:]*: Assembler messages:
[^:]*:22: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:22: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:22: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:22: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:22: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:22: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:23: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:24: Error: bad type in SIMD instruction -- `vcmp.f64 eq,q0,q1'
[^:]*:25: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:27: Error: syntax error -- `vcmpeq.f32 eq,q0,q1'
[^:]*:28: Error: syntax error -- `vcmpeq.f32 eq,q0,q1'
[^:]*:30: Error: syntax error -- `vcmpeq.f32 eq,q0,q1'
[^:]*:31: Error: vector predicated instruction should be in VPT/VPST block -- `vcmpt.f32 eq,q0,q1'
[^:]*:33: Error: instruction missing MVE vector predication code -- `vcmp.f32 eq,q0,q1'
[^:]*:35: Error: syntax error -- `vcmpeq.f32 eq,q0,r1'
[^:]*:36: Error: syntax error -- `vcmpeq.f32 eq,q0,r1'
[^:]*:38: Error: syntax error -- `vcmpeq.f32 eq,q0,r1'
[^:]*:39: Error: vector predicated instruction should be in VPT/VPST block -- `vcmpt.f32 eq,q0,r1'
[^:]*:41: Error: instruction missing MVE vector predication code -- `vcmp.f32 eq,q0,r1'
