#!/bin/sh

# pr20717.sh -- test --gc-sections for an unused orphan section
# when the last section in the linker script has a KEEP statement.

# Copyright (C) 2016-2020 Free Software Foundation, Inc.
# Written by Igor Kudrin  <ikudrin@accesssoftek.com>

# This file is part of gold.

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
# MA 02110-1301, USA.


check()
{
    file=$1
    pattern=$2
    if grep -q "$pattern" "$file"
    then
        echo "Garbage collection failed to collect :"
        echo "   $pattern"
	exit 1
    fi
}

check pr20717.stdout "unused"

