[^:]*: Assembler messages:
[^:]*:10: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.8 q0,\[r0,#128\]'
[^:]*:11: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.8 q0,\[r0,#-128\]'
[^:]*:12: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.16 q0,\[r0,#128\]'
[^:]*:13: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.16 q0,\[r0,#-128\]'
[^:]*:14: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.32 q0,\[r0,#128\]'
[^:]*:15: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.32 q0,\[r0,#-128\]'
[^:]*:16: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.8 q0,\[r0,#128\]!'
[^:]*:17: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.8 q0,\[r0,#-128\]!'
[^:]*:18: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.16 q0,\[r0,#128\]!'
[^:]*:19: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.16 q0,\[r0,#-128\]!'
[^:]*:20: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.32 q0,\[r0,#128\]!'
[^:]*:21: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.32 q0,\[r0,#-128\]!'
[^:]*:22: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.8 q0,\[r0\],#128'
[^:]*:23: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.8 q0,\[r0\],#-128'
[^:]*:24: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.16 q0,\[r0\],#128'
[^:]*:25: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.16 q0,\[r0\],#-128'
[^:]*:26: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.32 q0,\[r0\],#128'
[^:]*:27: Error: immediate must be in the range of \+/-\[0,127\] -- `vstrb.32 q0,\[r0\],#-128'
[^:]*:28: Error: lo register required -- `vstrb.16 q0,\[r10,#2\]'
[^:]*:29: Error: lo register required -- `vstrb.16 q0,\[r10,#2\]!'
[^:]*:30: Error: lo register required -- `vstrb.16 q0,\[r10\],#2'
[^:]*:31: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:32: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:33: Warning: instruction is UNPREDICTABLE with PC operand
[^:]*:34: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:34: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:34: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:34: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:34: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:34: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:35: Error: bad element type for instruction -- `vstrb.u16 q0,\[r0\]'
[^:]*:36: Error: bad element type for instruction -- `vstrb.s16 q0,\[r0\]'
[^:]*:37: Error: bad element type for instruction -- `vstrb.f16 q0,\[r0\]'
[^:]*:38: Error: bad element type for instruction -- `vstrb.p16 q0,\[r0\]'
[^:]*:39: Error: bad element type for instruction -- `vstrb.u32 q0,\[r0\]'
[^:]*:40: Error: bad element type for instruction -- `vstrb.s32 q0,\[r0\]'
[^:]*:41: Error: bad element type for instruction -- `vstrb.f32 q0,\[r0\]'
[^:]*:42: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0,#1\]'
[^:]*:43: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0,#17\]'
[^:]*:44: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0,#-17\]'
[^:]*:45: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0,#256\]'
[^:]*:46: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0,#-256\]'
[^:]*:47: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0,#1\]'
[^:]*:48: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0,#17\]'
[^:]*:49: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0,#-17\]'
[^:]*:50: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0,#256\]'
[^:]*:51: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0,#-256\]'
[^:]*:52: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0,#1\]!'
[^:]*:53: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0,#17\]!'
[^:]*:54: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0,#-17\]!'
[^:]*:55: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0,#256\]!'
[^:]*:56: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0,#-256\]!'
[^:]*:57: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0,#1\]!'
[^:]*:58: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0,#17\]!'
[^:]*:59: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0,#-17\]!'
[^:]*:60: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0,#256\]!'
[^:]*:61: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0,#-256\]!'
[^:]*:62: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0\],#1'
[^:]*:63: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0\],#17'
[^:]*:64: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0\],#-17'
[^:]*:65: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0\],#256'
[^:]*:66: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.16 q0,\[r0\],#-256'
[^:]*:67: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0\],#1'
[^:]*:68: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0\],#17'
[^:]*:69: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0\],#-17'
[^:]*:70: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0\],#256'
[^:]*:71: Error: immediate must be a multiple of 2 in the range of \+/-\[0,254\] -- `vstrh.32 q0,\[r0\],#-256'
[^:]*:72: Error: lo register required -- `vstrh.32 q0,\[r10,#4\]'
[^:]*:73: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:74: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:75: Warning: instruction is UNPREDICTABLE with PC operand
[^:]*:76: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:76: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:76: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:76: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:76: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:76: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:77: Error: bad element type for instruction -- `vstrh.8 q0,\[r0\]'
[^:]*:78: Error: bad element type for instruction -- `vstrh.u8 q0,\[r0\]'
[^:]*:79: Error: bad element type for instruction -- `vstrh.s8 q0,\[r0\]'
[^:]*:80: Error: bad element type for instruction -- `vstrh.p8 q0,\[r0\]'
[^:]*:81: Error: bad element type for instruction -- `vstrh.u32 q0,\[r0\]'
[^:]*:82: Error: bad element type for instruction -- `vstrh.s32 q0,\[r0\]'
[^:]*:83: Error: bad element type for instruction -- `vstrh.f32 q0,\[r0\]'
[^:]*:84: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#3\]'
[^:]*:85: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#-3\]'
[^:]*:86: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#514\]'
[^:]*:87: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#-258\]'
[^:]*:88: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#258\]'
[^:]*:89: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#516\]'
[^:]*:90: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#-516\]'
[^:]*:91: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#3\]!'
[^:]*:92: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#-3\]!'
[^:]*:93: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#514\]!'
[^:]*:94: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#-258\]!'
[^:]*:95: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#258\]!'
[^:]*:96: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#516\]!'
[^:]*:97: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0,#-516\]!'
[^:]*:98: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0\],#3'
[^:]*:99: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0\],#-3'
[^:]*:100: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0\],#514'
[^:]*:101: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0\],#-258'
[^:]*:102: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0\],#258'
[^:]*:103: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0\],#516'
[^:]*:104: Error: immediate must be a multiple of 4 in the range of \+/-\[0,508\] -- `vstrw.32 q0,\[r0\],#-516'
[^:]*:105: Warning: instruction is UNPREDICTABLE with SP operand
[^:]*:106: Warning: instruction is UNPREDICTABLE with PC operand
[^:]*:107: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:107: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:107: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:107: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:107: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:107: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:108: Error: bad element type for instruction -- `vstrw.8 q0,\[r0\]'
[^:]*:109: Error: bad element type for instruction -- `vstrw.u8 q0,\[r0\]'
[^:]*:110: Error: bad element type for instruction -- `vstrw.s8 q0,\[r0\]'
[^:]*:111: Error: bad element type for instruction -- `vstrw.p8 q0,\[r0\]'
[^:]*:112: Error: bad element type for instruction -- `vstrw.16 q0,\[r0\]'
[^:]*:113: Error: bad element type for instruction -- `vstrw.u16 q0,\[r0\]'
[^:]*:114: Error: bad element type for instruction -- `vstrw.s16 q0,\[r0\]'
[^:]*:115: Error: bad element type for instruction -- `vstrw.f16 q0,\[r0\]'
[^:]*:116: Error: bad element type for instruction -- `vstrw.p16 q0,\[r0\]'
[^:]*:118: Error: syntax error -- `vstrbeq.8 q0,\[r0\]'
[^:]*:119: Error: syntax error -- `vstrbeq.8 q0,\[r0\]'
[^:]*:121: Error: syntax error -- `vstrbeq.8 q0,\[r0\]'
[^:]*:122: Error: vector predicated instruction should be in VPT/VPST block -- `vstrbt.8 q0,\[r0\]'
[^:]*:124: Error: instruction missing MVE vector predication code -- `vstrb.8 q0,\[r0\]'
[^:]*:126: Error: syntax error -- `vstrheq.16 q0,\[r0\]'
[^:]*:127: Error: syntax error -- `vstrheq.16 q0,\[r0\]'
[^:]*:129: Error: syntax error -- `vstrheq.16 q0,\[r0\]'
[^:]*:130: Error: vector predicated instruction should be in VPT/VPST block -- `vstrht.16 q0,\[r0\]'
[^:]*:132: Error: instruction missing MVE vector predication code -- `vstrh.16 q0,\[r0\]'
[^:]*:134: Error: syntax error -- `vstrweq.32 q0,\[r0\]'
[^:]*:135: Error: syntax error -- `vstrweq.32 q0,\[r0\]'
[^:]*:137: Error: syntax error -- `vstrweq.32 q0,\[r0\]'
[^:]*:138: Error: vector predicated instruction should be in VPT/VPST block -- `vstrwt.32 q0,\[r0\]'
[^:]*:140: Error: instruction missing MVE vector predication code -- `vstrw.32 q0,\[r0\]'
