	movprfx   z0, z0
	MOVPRFX   Z0, Z0
	movprfx   z1, z0
	MOVPRFX   Z1, Z0
	movprfx   z31, z0
	MOVPRFX   Z31, Z0
	movprfx   z0, z2
	MOVPRFX   Z0, Z2
	movprfx   z0, z31
	MOVPRFX   Z0, Z31
	movprfx   z0.b, p0/z, z0.b
	MOVPRFX   Z0.B, P0/Z, Z0.B
	movprfx   z1.b, p0/z, z0.b
	MOVPRFX   Z1.B, P0/Z, Z0.B
	movprfx   z31.b, p0/z, z0.b
	MOVPRFX   Z31.B, P0/Z, Z0.B
	movprfx   z0.b, p2/z, z0.b
	MOVPRFX   Z0.B, P2/Z, Z0.B
	movprfx   z0.b, p7/z, z0.b
	MOVPRFX   Z0.B, P7/Z, Z0.B
	movprfx   z0.b, p0/z, z3.b
	MOVPRFX   Z0.B, P0/Z, Z3.B
	movprfx   z0.b, p0/z, z31.b
	MOVPRFX   Z0.B, P0/Z, Z31.B
	movprfx   z0.b, p0/m, z0.b
	MOVPRFX   Z0.B, P0/M, Z0.B
	movprfx   z1.b, p0/m, z0.b
	MOVPRFX   Z1.B, P0/M, Z0.B
	movprfx   z31.b, p0/m, z0.b
	MOVPRFX   Z31.B, P0/M, Z0.B
	movprfx   z0.b, p2/m, z0.b
	MOVPRFX   Z0.B, P2/M, Z0.B
	movprfx   z0.b, p7/m, z0.b
	MOVPRFX   Z0.B, P7/M, Z0.B
	movprfx   z0.b, p0/m, z3.b
	MOVPRFX   Z0.B, P0/M, Z3.B
	movprfx   z0.b, p0/m, z31.b
	MOVPRFX   Z0.B, P0/M, Z31.B
	movprfx   z0.h, p0/z, z0.h
	MOVPRFX   Z0.H, P0/Z, Z0.H
	movprfx   z1.h, p0/z, z0.h
	MOVPRFX   Z1.H, P0/Z, Z0.H
	movprfx   z31.h, p0/z, z0.h
	MOVPRFX   Z31.H, P0/Z, Z0.H
	movprfx   z0.h, p2/z, z0.h
	MOVPRFX   Z0.H, P2/Z, Z0.H
	movprfx   z0.h, p7/z, z0.h
	MOVPRFX   Z0.H, P7/Z, Z0.H
	movprfx   z0.h, p0/z, z3.h
	MOVPRFX   Z0.H, P0/Z, Z3.H
	movprfx   z0.h, p0/z, z31.h
	MOVPRFX   Z0.H, P0/Z, Z31.H
	movprfx   z0.h, p0/m, z0.h
	MOVPRFX   Z0.H, P0/M, Z0.H
	movprfx   z1.h, p0/m, z0.h
	MOVPRFX   Z1.H, P0/M, Z0.H
	movprfx   z31.h, p0/m, z0.h
	MOVPRFX   Z31.H, P0/M, Z0.H
	movprfx   z0.h, p2/m, z0.h
	MOVPRFX   Z0.H, P2/M, Z0.H
	movprfx   z0.h, p7/m, z0.h
	MOVPRFX   Z0.H, P7/M, Z0.H
	movprfx   z0.h, p0/m, z3.h
	MOVPRFX   Z0.H, P0/M, Z3.H
	movprfx   z0.h, p0/m, z31.h
	MOVPRFX   Z0.H, P0/M, Z31.H
	movprfx   z0.s, p0/z, z0.s
	MOVPRFX   Z0.S, P0/Z, Z0.S
	movprfx   z1.s, p0/z, z0.s
	MOVPRFX   Z1.S, P0/Z, Z0.S
	movprfx   z31.s, p0/z, z0.s
	MOVPRFX   Z31.S, P0/Z, Z0.S
	movprfx   z0.s, p2/z, z0.s
	MOVPRFX   Z0.S, P2/Z, Z0.S
	movprfx   z0.s, p7/z, z0.s
	MOVPRFX   Z0.S, P7/Z, Z0.S
	movprfx   z0.s, p0/z, z3.s
	MOVPRFX   Z0.S, P0/Z, Z3.S
	movprfx   z0.s, p0/z, z31.s
	MOVPRFX   Z0.S, P0/Z, Z31.S
	movprfx   z0.s, p0/m, z0.s
	MOVPRFX   Z0.S, P0/M, Z0.S
	movprfx   z1.s, p0/m, z0.s
	MOVPRFX   Z1.S, P0/M, Z0.S
	movprfx   z31.s, p0/m, z0.s
	MOVPRFX   Z31.S, P0/M, Z0.S
	movprfx   z0.s, p2/m, z0.s
	MOVPRFX   Z0.S, P2/M, Z0.S
	movprfx   z0.s, p7/m, z0.s
	MOVPRFX   Z0.S, P7/M, Z0.S
	movprfx   z0.s, p0/m, z3.s
	MOVPRFX   Z0.S, P0/M, Z3.S
	movprfx   z0.s, p0/m, z31.s
	MOVPRFX   Z0.S, P0/M, Z31.S
	movprfx   z0.d, p0/z, z0.d
	MOVPRFX   Z0.D, P0/Z, Z0.D
	movprfx   z1.d, p0/z, z0.d
	MOVPRFX   Z1.D, P0/Z, Z0.D
	movprfx   z31.d, p0/z, z0.d
	MOVPRFX   Z31.D, P0/Z, Z0.D
	movprfx   z0.d, p2/z, z0.d
	MOVPRFX   Z0.D, P2/Z, Z0.D
	movprfx   z0.d, p7/z, z0.d
	MOVPRFX   Z0.D, P7/Z, Z0.D
	movprfx   z0.d, p0/z, z3.d
	MOVPRFX   Z0.D, P0/Z, Z3.D
	movprfx   z0.d, p0/z, z31.d
	MOVPRFX   Z0.D, P0/Z, Z31.D
	movprfx   z0.d, p0/m, z0.d
	MOVPRFX   Z0.D, P0/M, Z0.D
	movprfx   z1.d, p0/m, z0.d
	MOVPRFX   Z1.D, P0/M, Z0.D
	movprfx   z31.d, p0/m, z0.d
	MOVPRFX   Z31.D, P0/M, Z0.D
	movprfx   z0.d, p2/m, z0.d
	MOVPRFX   Z0.D, P2/M, Z0.D
	movprfx   z0.d, p7/m, z0.d
	MOVPRFX   Z0.D, P7/M, Z0.D
	movprfx   z0.d, p0/m, z3.d
	MOVPRFX   Z0.D, P0/M, Z3.D
	movprfx   z0.d, p0/m, z31.d
	MOVPRFX   Z0.D, P0/M, Z31.D
