.*shift-bad-pc.s: Assembler messages:
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:20: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
.*shift-bad-pc.s:21: Warning: using r15 results in unpredictable behaviour
