[^:]*: Assembler messages:
[^:]*:10: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:10: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:10: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:10: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:10: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:10: Warning: instruction is UNPREDICTABLE in an IT block
[^:]*:12: Error: syntax error -- `veoreq q0,q1,q2'
[^:]*:13: Error: syntax error -- `veoreq q0,q1,q2'
[^:]*:15: Error: syntax error -- `veoreq q0,q1,q2'
[^:]*:17: Error: instruction missing MVE vector predication code -- `veor q0,q1,q2'
[^:]*:18: Error: vector predicated instruction should be in VPT/VPST block -- `veort q0,q1,q2'
