.*:
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: unsupported constant in relocation
.*: TLS relocation against a constant
.*: TLS relocation against a constant
.*: TLS relocation against a constant
.*: TLS relocation against a constant
.*: TLS relocation against a constant
.*: TLS relocation against a constant
.*: TLS relocation against a constant
.*: TLS relocation against a constant
.*: TLS relocation against a constant
.*: TLS relocation against a constant
.*: TLS relocation against a constant
.*: TLS relocation against a constant
.*: TLS relocation against a constant
.*: TLS relocation against a constant
