 	jsr d2
	jsr (2,y)
	jsr (+y)
	jsr (-y)
	jsr (y+)
	jsr (y-)
	jsr (+x)
	jsr (-x)
	jsr (x+)
	jsr (x-)
	jsr (-s)
	jsr (s+)
 	jsr (d3,x)
 	jsr (30,d6)
 	jsr (93,p)
	jsr [45,y]
	jsr 12
	jsr 4021
	jsr 114321
	jsr [492134]
	jsr (0,x)
