
tmpdir/cmse_main_sec_debug:     .*

Contents of the \.debug_info section:

  Compilation Unit @ offset 0x0:
   Length:        0x34 \(32-bit\)
   Version:       4
   Abbrev Offset: 0x0
   Pointer Size:  4
 <0><b>: Abbrev Number: 1 \(DW_TAG_compile_unit\)
    <c>   DW_AT_producer    : \(indirect string, offset: 0x[a-f0-9]+\): GNU C17 10.0.0 20190617
    <10>   DW_AT_language    : 12	\(ANSI C99\)
    <11>   DW_AT_name        : \(indirect string, offset: 0x[a-f0-9]+\): sec.c
    <15>   DW_AT_comp_dir    : \(indirect string, offset: 0x[a-f0-9]+\): Blinky
    <19>   DW_AT_ranges      : 0x[a-f0-9]+
    <1d>   DW_AT_low_pc      : 0x[a-f0-9]+
    <21>   DW_AT_stmt_list   : 0x[a-f0-9]+
 <1><25>: Abbrev Number: 2 \(DW_TAG_subprogram\)
    <26>   DW_AT_external    : 1
    <26>   DW_AT_name        : \(indirect string, offset: 0x[a-f0-9]+\): SecureLED_On
    <2a>   DW_AT_decl_file   : 1
    <2b>   DW_AT_decl_line   : 2
    <2c>   DW_AT_decl_column : 1
    <2d>   DW_AT_low_pc      : 0x[a-f0-9]+
    <31>   DW_AT_high_pc     : 0x[a-f0-9]+
    <35>   DW_AT_frame_base  : 1 byte block: 9c 	\(DW_OP_call_frame_cfa\)
    <37>   DW_AT_GNU_all_call_sites: 1
 <1><37>: Abbrev Number: 0
