[^:]*: Assembler messages:
[^:]*:6: Error: shift expression expected -- `sub r0,r0,#:pc_g0:\(foo\)'
[^:]*:7: Error: shift expression expected -- `subs r0,r0,#:pc_g0:\(foo\)'
[^:]*:10: Error: unknown group relocation -- `add r0,r0,#:pc_g2_nc:\(foo\)'
[^:]*:11: Error: unknown group relocation -- `add r0,r0,#:sb_g2_nc:\(foo\)'
