.*: Assembler messages:
.*:19: Error: branch to a symbol in another ISA mode
.*:25: Error: branch to a symbol in another ISA mode
.*:27: Error: branch to a symbol in another ISA mode
.*:29: Error: branch to a symbol in another ISA mode
.*:31: Error: branch to a symbol in another ISA mode
.*:33: Error: branch to a symbol in another ISA mode
.*:21: Error: branch to a symbol in another ISA mode
.*:23: Error: branch to a symbol in another ISA mode
